#!/bin/sh
# \
exec fltkwish "$0" --  ${1+"$@"}

# --- button.tcl --- Test harness for fltk buttons

# Copyright(C) I.B.Findleton, 2000. All Rights Reserved

package require Fltk

Application set -name "Button Test"

#puts "Application"

# This will set the color scheme to an OpenGL based rendering scheme for widgets

#set scheme [Scheme shiny -name "Brass Buttons" -background brass -bg2 brass]
#set scheme [Scheme normal -name "Default" -background tan -bg2 tan]
set scheme [Scheme plastic]

#puts "Scheme Done"

Destroy root

Toplevel root -h 300

# Add some options to the database that configure a button. This version supports
# some option names in french as well as in english, so some of the option keys
# are the french names, just to test things out!

Option clear Button
Option clear Label

#puts "Clear Options"

Option add Button.x 20
Option add Button.y 50
Option add Button.largeur 150
Option add Button.height 100
Option add Button.tooltip "Button Tip for %w with label %l"

set height [Option add Button.longeur 30]

Option add Label.relief ridge

# Make nicer buttons if not using GL...

if { $scheme != "Brass Buttons" } {
	Option add Button.relief raised
#	Option add Button.downrelief sunken
   	}

# Set the values of the origin of the labels

Option add Label.x 20
Option add Label.y 50
Option add Label.height 30

#puts "Options done"

# Add a menu

set m1 [Menu root.m1]
$m1 add command -text "Exit" -command { exit }

#puts "Menu done"

# Create a few buttons of various types

set b1 [Button root.b1]
set b2 [LightButton root.b2 -text "LightButton" -command { ButtonPress root.b2 }]
set b3 [RoundButton root.b3 -text "Round Button" -command { ButtonPress root.b3 }]
set b4 [RepeatButton root.b4 -text "Repeat Button" -command { ButtonPress root.b4 }]
set b5 [ReturnButton root.b5 -text "Return Button" -command { ButtonPress root.b5 }]
set b6 [DiamondButton root.b6 -text "Diamond Button" -command { ButtonPress root.b6 }]
set b7 [ImageButton root.b7 -text "Image Button" -command { ButtonPress root.b7 }]
set b8 [Button root.b8 -text "Exit" -command { Exit }]

#puts "Created buttons"

# Configure the buttons. Here they are positioned relative to the default
# location specified in the option database

$b1 config -text "Push Me" -command { ButtonPress $b1 }
$b2 config -y +$height -bg2 red
$b3 config -y +[expr 2 * $height] -bg2 green
$b4 config -y +[expr 3 * $height]
$b5 config -y +[expr 4 * $height]
$b6 config -y +[expr 5 * $height]
$b7 config -y +[expr 6 * $height] -bg2 blue
$b8 config -y +[expr 7 * $height]

#puts "Config Buttons"

# Action for when the button is pressed

proc ButtonPress { w } {
	set value [$w cget -value]
   if { $value == "1" } {
		puts "$w : Button Pressed [$w cget -label] has value $value"
   } else {
   	puts "$w : Button Released [$w cget -label] has value $value"
      }
   }

# Some actions to take then the mouse is over the button. These are
# specified as class events for the button class

Bind Button <Enter> { %W config -fg red }
Bind Button <Leave> { %W config -fg black }

#puts "Button bindings"

# A label widget

set l1 [Label root.l1 -x +180 -text "A Label"]

Bind Label <Enter> { %W config -bg silver }
Bind Label <Leave> { %W config -bg brass }

#puts "Label bindings"

Show root
