#!/bin/sh
# \
exec tclsh "$0" ${1+"$@"}

# --- GenColor.tcl --- Generate a database of color definitions

# Copyright(C) I.B.Findleton, 2001. All Rights Reserved

# This script will convert the long list of color names found at the end
# to a piece of c++ code that can be compiled for use by a few
# functions that will look up a name and return an RGB specification.

set list {}

catch { unset Colors }

# Check if a name has the same root as another name

proc IsThisColor { name other } {

	set last [expr [string length $name] - 1]

   if { [string range $other 0 $last] == $name } {
   	return 1
   } else { return 0 }
	}

# Get the list of entries that match a name

proc GetMatchingNames { name } {

	global list

   set matches {}

   foreach entry $list {
   	if { [IsThisColor $name $entry] } {
      	lappend matches $entry
         }
      }

   return [lsort $matches]
}

# Check if a color is in the list of known colors

proc IsNotInList { list red green blue } {

	global Colors

   foreach entry $list {
   	if { $Colors($entry) == " $red, $green, $blue " } {
      	return 0
      	}
      }

   return 1
	}

# Add a color to the list of color names

proc AddColor { name red green blue } {

	global list Colors

   set name [string tolower $name]

   set red [expr int($red * 255.0)]
   set green [expr int($green * 255.0)]
   set blue [expr int ($blue * 255.0)]

   set matches [GetMatchingNames $name]

	if { [llength $matches] == 0 } {
   	lappend list $name
      set Colors($name) " $red, $green, $blue "
   } else {
   	if { [IsNotInList $matches $red $green $blue] } {
      	set name "[lindex $matches 0][llength $matches]"
         lappend list $name
         set Colors($name) " $red, $green, $blue "
         }
      }
   }

set fd [open "colors.cpp" w]

puts $fd "typedef struct { unsigned char r,g,b; } Rgb;\n"
puts $fd "typedef struct \{ char *name; Rgb color; \} ColorEntry;\n"

puts $fd "static ColorEntry colors\[\] = \{\n"

AddColor aquamarine  .439216 .858824 .576471
AddColor black  0 0 0
AddColor blue   0 0 1
AddColor blueviolet  .623529 .372549 .623529
AddColor brilliantred .68 .405 .405
AddColor brown  .647059 .164706 .164706
AddColor cadetblue  .372549 .623529 .623529
AddColor coral  1 .498039 0
AddColor cornflowerblue .258824 .258824 .435294
AddColor cyan   0 1 1
AddColor darkbrown  .1941 .0492 .0492
AddColor darkgray  .329412 .329412 .329412
AddColor darkgrey  .329412 .329412 .329412
AddColor darkgreen  .184314 .309804 .184314
AddColor darkolivegreen .309804 .309804 .184314
AddColor darkorchid  .6 .196078 .8
AddColor darkplum   .45 .34 .45
AddColor darkslateblue .419608 .137255 .556863
AddColor darkslategray .184314 .309804 .309804
AddColor darkslategrey .184314 .309804 .309804
AddColor darktan  .51 .35 .264
AddColor darkturquoise .439216 .576471 .858824
AddColor dimbrown .384 .096 .096
AddColor dimgray  .329412 .329412 .329412
AddColor dimgrey  .329412 .329412 .329412
AddColor firebrick  .556863 .137255 .137255
AddColor forestgreen  .137255 .556863 .137255
AddColor gold   .6 .5 .26
AddColor goldenrod  .858824 .858824 .439216
AddColor gray   .752941 .752941 .752941
AddColor green  0 1 0
AddColor greenyellow  .576471 .858824 .439216
AddColor grey   .752941 .752941 .752941
AddColor indianred  .309804 .184314 .184314
AddColor khaki  .623529 .623529 .372549
AddColor lightblue  .74902 .847059 .847059
AddColor lightgray  .658824 .658824 .658824
AddColor lightgrey  .658824 .658824 .658824
AddColor lightskyblue .529412 .807843 .921569
AddColor lightsteelblue .560784 .560784 .737255
AddColor limegreen  .196078 .8 .196078
AddColor magenta  1 0 1
AddColor maroon  .556863 .137255 .419608
AddColor mediumaquamarine .196078 .8 .6
AddColor mediumblue  .196078 .196078 .8
AddColor mediumbrown  .455 .112 .115
AddColor mediumforestgreen .419608 .556863 .137255
AddColor mediumgoldenrod .917647 .917647 .678431
AddColor mediumgray  .5 .5 .5
AddColor mediumgrey  .5 .5 .5
AddColor mediumorchid .576471 .439216 .858824
AddColor mediumplum .55 .40 .55
AddColor mediumseagreen .258824 .435294 .258824
AddColor mediumslateblue .498039 0 1
AddColor mediumspringgreen .498039 1 0
AddColor mediumturquoise .439216 .858824 .858824
AddColor mediumvioletred .858824 .439216 .576471
AddColor midnightblue .184314 .184314 .309804
AddColor navy   .137255 .137255 .556863
AddColor navyblue  .137255 .137255 .556863
AddColor orange  .8 .196078 .196078
AddColor orangered  1 0 .498039
AddColor orchid  .858824 .439216 .858824
AddColor palegreen  .560784 .737255 .560784
AddColor pink   .737255 .560784 .560784
AddColor plum   .917647 .678431 .917647
AddColor red   1 0 0
AddColor salmon  .435294 .258824 .258824
AddColor seagreen  .137255 .556863 .419608
AddColor sienna  .556863 .419608 .137255
AddColor silver  .6 .6 .7
AddColor skyblue  .196078 .6 .8
AddColor slateblue  0 .498039 1
AddColor springgreen  0 1 .498039
AddColor steelblue  .137255 .419608 .556863
AddColor mediumtan   .858824 .576471 .439216
AddColor thistle  .847059 .74902 .847059
AddColor turquoise  .678431 .917647 .917647
AddColor violet  .309804 .184314 .309804
AddColor violetred  .8 .196078 .6
AddColor wheat  .847059 .847059 .74902
AddColor white  1 1 1
AddColor yellow  1 1 0
AddColor yellowgreen  .6 .8 .196078

AddColor Gray05  0.05  0.05  0.05
AddColor Gray05  0.05  0.05  0.05
AddColor Gray10  0.10  0.10  0.10
AddColor Gray15  0.15  0.15  0.15
AddColor Gray20  0.20  0.20  0.20
AddColor Gray25  0.25  0.25  0.25
AddColor Gray30  0.30  0.30  0.30
AddColor Gray35  0.35  0.35  0.35
AddColor Gray40  0.40  0.40  0.40
AddColor Gray45  0.45  0.45  0.45
AddColor Gray50  0.50  0.50  0.50
AddColor Gray55  0.55  0.55  0.55
AddColor Gray60  0.60  0.60  0.60
AddColor Gray65  0.65  0.65  0.65
AddColor Gray70  0.70  0.70  0.70
AddColor Gray75  0.75  0.75  0.75
AddColor Gray80  0.80  0.80  0.80
AddColor Gray85  0.85  0.85  0.85
AddColor Gray90  0.90  0.90  0.90
AddColor Gray95  0.95  0.95  0.95
AddColor DimGray  0.329412  0.329412  0.329412
AddColor DimGrey  0.329412  0.329412  0.329412
AddColor Gray  0.752941  0.752941  0.752941
AddColor Grey  0.752941  0.752941  0.752941
AddColor LightGray  0.658824  0.658824  0.658824
AddColor LightGrey  0.658824  0.658824  0.658824
AddColor VeryLightGrey  0.80  0.80  0.80
AddColor VeryLightGray  0.80  0.80  0.80
AddColor Clear  1.0  1.0  1.0
AddColor White  1.0  1.0  1.0
AddColor Red  1.0 0 0
AddColor Green  0 1.0 0
AddColor Blue  0 0 1.0
AddColor Yellow  1.0  1.0 0
AddColor Cyan  0  1.0  1.0
AddColor Magenta  1.0 0  1.0
AddColor Black  0.0  0.0  0.0
AddColor Aquamarine  0.439216  0.858824  0.576471
AddColor BlueViolet  0.62352  0.372549  0.623529
AddColor Brown  0.647059  0.164706  0.164706
AddColor CadetBlue  0.372549  0.623529  0.623529
AddColor Coral  1.0  0.498039  0.0
AddColor CornflowerBlue  0.258824  0.258824  0.435294
AddColor DarkGreen  0.184314  0.309804  0.184314
AddColor DarkOliveGreen  0.309804  0.309804  0.184314
AddColor DarkOrchid  0.6  0.196078  0.8
AddColor DarkSlateBlue  0.419608  0.137255  0.556863
AddColor DarkSlateGray  0.184314  0.309804  0.309804
AddColor DarkSlateGrey  0.184314  0.309804  0.309804
AddColor DarkTurquoise  0.439216  0.576471  0.858824
AddColor Firebrick  0.556863  0.137255  0.137255
AddColor ForestGreen  0.137255  0.556863  0.137255
AddColor Gold  0.8  0.498039  0.196078
AddColor Goldenrod  0.858824  0.858824  0.439216
AddColor GreenYellow  0.576471  0.858824  0.439216
AddColor IndianRed  0.309804  0.184314  0.184314
AddColor Khaki  0.623529  0.623529  0.372549
AddColor LightBlue  0.74902  0.847059  0.847059
AddColor LightSteelBlue  0.560784  0.560784  0.737255
AddColor LimeGreen  0.196078  0.8  0.196078
AddColor Maroon  0.556863  0.137255  0.419608
AddColor MediumAquamarine  0.196078  0.8  0.6
AddColor MediumBlue  0.196078  0.196078  0.8
AddColor MediumForestGreen  0.419608  0.556863  0.137255
AddColor MediumGoldenrod  0.917647  0.917647  0.678431
AddColor MediumOrchid  0.576471  0.439216  0.858824
AddColor MediumSeaGreen  0.258824  0.435294  0.258824
AddColor MediumSlateBlue  0.498039 0  1.0
AddColor MediumSpringGreen  0.498039  1.0 0
AddColor MediumTurquoise  0.439216  0.858824  0.858824
AddColor MediumVioletRed  0.858824  0.439216  0.576471
AddColor MidnightBlue  0.184314  0.184314  0.309804
AddColor Navy  0.137255  0.137255  0.556863
AddColor NavyBlue  0.137255  0.137255  0.556863
AddColor Orange  1  0.5  0.0
AddColor OrangeRed  1.0 0  0.498039
AddColor Orchid  0.858824  0.439216  0.858824
AddColor PaleGreen  0.560784  0.737255  0.560784
AddColor Pink  0.737255  0.560784  0.560784
AddColor Plum  0.917647  0.678431  0.917647
AddColor Salmon  0.435294  0.258824  0.258824
AddColor SeaGreen  0.137255  0.556863  0.419608
AddColor Sienna  0.556863  0.419608  0.137255
AddColor SkyBlue  0.196078  0.6  0.8
AddColor SlateBlue  0 0.498039  1.0
AddColor SpringGreen  0 1.0  0.498039
AddColor SteelBlue  0.137255  0.419608  0.556863
AddColor Tan  0.858824  0.576471  0.439216
AddColor Thistle  0.847059  0.74902  0.847059
AddColor Turquoise  0.678431  0.917647  0.917647
AddColor Violet  0.309804  0.184314  0.309804
AddColor VioletRed  0.8  0.196078  0.6
AddColor Wheat  0.847059  0.847059  0.74902
AddColor YellowGreen  0.6  0.8  0.196078
AddColor SummerSky  0.22  0.69  0.87
AddColor RichBlue  0.35  0.35  0.67
AddColor Brass  0.71  0.65  0.26
AddColor Copper  0.72  0.45  0.20
AddColor Bronze  0.55  0.47  0.14
AddColor Bronze2  0.65  0.49  0.24
AddColor Silver  0.90  0.91  0.98
AddColor BrightGold  0.85  0.85  0.10
AddColor OldGold  0.81  0.71  0.23
AddColor Feldspar  0.82  0.57  0.46
AddColor Quartz  0.85  0.85  0.95
AddColor Mica  0 0 0
AddColor NeonPink  1.00  0.43  0.78
AddColor DarkPurple  0.53  0.12  0.47
AddColor NeonBlue  0.30  0.30  1.00
AddColor CoolCopper  0.85  0.53  0.10
AddColor MandarinOrange  0.89  0.47  0.20
AddColor LightWood  0.91  0.76  0.65
AddColor MediumWood  0.65  0.50  0.39
AddColor DarkWood  0.52  0.37  0.26
AddColor SpicyPink  1.00  0.11  0.68
AddColor SemiSweetChoc  0.42  0.26  0.15
AddColor BakersChoc  0.36  0.20  0.09
AddColor Flesh  0.96  0.80  0.69
AddColor NewTan  0.92  0.78  0.62
AddColor NewMidnightBlue  0.00  0.00  0.61
AddColor VeryDarkBrown  0.35  0.16  0.14
AddColor DarkBrown  0.36  0.25  0.20
AddColor DarkTan  0.59  0.41  0.31
AddColor GreenCopper  0.32  0.49  0.46
AddColor DkGreenCopper  0.29  0.46  0.43
AddColor DustyRose  0.52  0.39  0.39
AddColor HuntersGreen  0.13  0.37  0.31
AddColor Scarlet  0.55  0.09 0.09
AddColor snow 1.0 0.980392156863 0.980392156863
AddColor ghostwhite 0.972549019608 0.972549019608 1.0
AddColor GhostWhite 0.972549019608 0.972549019608 1.0
AddColor whitesmoke 0.960784313725 0.960784313725 0.960784313725
AddColor WhiteSmoke 0.960784313725 0.960784313725 0.960784313725
AddColor gainsboro 0.862745098039 0.862745098039 0.862745098039
AddColor floralwhite 1.0 0.980392156863 0.941176470588
AddColor FloralWhite 1.0 0.980392156863 0.941176470588
AddColor oldlace 0.992156862745 0.960784313725 0.901960784314
AddColor OldLace 0.992156862745 0.960784313725 0.901960784314
AddColor linen 0.980392156863 0.941176470588 0.901960784314
AddColor antiquewhite 0.980392156863 0.921568627451 0.843137254902
AddColor AntiqueWhite 0.980392156863 0.921568627451 0.843137254902
AddColor papayawhip 1.0 0.937254901961 0.835294117647
AddColor PapayaWhip 1.0 0.937254901961 0.835294117647
AddColor blanchedalmond 1.0 0.921568627451 0.803921568627
AddColor BlanchedAlmond 1.0 0.921568627451 0.803921568627
AddColor bisque 1.0 0.894117647059 0.76862745098
AddColor peachpuff 1.0 0.854901960784 0.725490196078
AddColor PeachPuff 1.0 0.854901960784 0.725490196078
AddColor navajowhite 1.0 0.870588235294 0.678431372549
AddColor NavajoWhite 1.0 0.870588235294 0.678431372549
AddColor moccasin 1.0 0.894117647059 0.709803921569
AddColor cornsilk 1.0 0.972549019608 0.862745098039
AddColor ivory 1.0 1.0 0.941176470588
AddColor lemonchiffon 1.0 0.980392156863 0.803921568627
AddColor LemonChiffon 1.0 0.980392156863 0.803921568627
AddColor seashell 1.0 0.960784313725 0.933333333333
AddColor honeydew 0.941176470588 1.0 0.941176470588
AddColor mintcream 0.960784313725 1.0 0.980392156863
AddColor MintCream 0.960784313725 1.0 0.980392156863
AddColor azure 0.941176470588 1.0 1.0
AddColor aliceblue 0.941176470588 0.972549019608 1.0
AddColor AliceBlue 0.941176470588 0.972549019608 1.0
AddColor lavender 0.901960784314 0.901960784314 0.980392156863
AddColor lavenderblush 1.0 0.941176470588 0.960784313725
AddColor LavenderBlush 1.0 0.941176470588 0.960784313725
AddColor mistyrose 1.0 0.894117647059 0.882352941176
AddColor MistyRose 1.0 0.894117647059 0.882352941176
AddColor white 1.0 1.0 1.0
AddColor black 0.0 0.0 0.0
AddColor darkslate 0.18431372549 0.309803921569 0.309803921569
AddColor DarkSlateGray 0.18431372549 0.309803921569 0.309803921569
AddColor darkslate 0.18431372549 0.309803921569 0.309803921569
AddColor DarkSlateGrey 0.18431372549 0.309803921569 0.309803921569
AddColor dimgray 0.411764705882 0.411764705882 0.411764705882
AddColor DimGray 0.411764705882 0.411764705882 0.411764705882
AddColor dimgrey 0.411764705882 0.411764705882 0.411764705882
AddColor DimGrey 0.411764705882 0.411764705882 0.411764705882
AddColor slategray 0.439215686275 0.501960784314 0.564705882353
AddColor SlateGray 0.439215686275 0.501960784314 0.564705882353
AddColor slategrey 0.439215686275 0.501960784314 0.564705882353
AddColor SlateGrey 0.439215686275 0.501960784314 0.564705882353
AddColor lightslate 0.466666666667 0.533333333333 0.6
AddColor LightSlateGray 0.466666666667 0.533333333333 0.6
AddColor lightslate 0.466666666667 0.533333333333 0.6
AddColor LightSlateGrey 0.466666666667 0.533333333333 0.6
AddColor gray 0.745098039216 0.745098039216 0.745098039216
AddColor grey 0.745098039216 0.745098039216 0.745098039216
AddColor lightgrey 0.827450980392 0.827450980392 0.827450980392
AddColor LightGrey 0.827450980392 0.827450980392 0.827450980392
AddColor lightgray 0.827450980392 0.827450980392 0.827450980392
AddColor LightGray 0.827450980392 0.827450980392 0.827450980392
AddColor midnightblue 0.0980392156863 0.0980392156863 0.439215686275
AddColor MidnightBlue 0.0980392156863 0.0980392156863 0.439215686275
AddColor navy 0.0 0.0 0.501960784314
AddColor navyblue 0.0 0.0 0.501960784314
AddColor NavyBlue 0.0 0.0 0.501960784314
AddColor cornflowerblue 0.392156862745 0.58431372549 0.929411764706
AddColor CornflowerBlue 0.392156862745 0.58431372549 0.929411764706
AddColor darkslate 0.282352941176 0.239215686275 0.545098039216
AddColor DarkSlateBlue 0.282352941176 0.239215686275 0.545098039216
AddColor slateblue 0.41568627451 0.352941176471 0.803921568627
AddColor SlateBlue 0.41568627451 0.352941176471 0.803921568627
AddColor mediumslate 0.482352941176 0.407843137255 0.933333333333
AddColor MediumSlateBlue 0.482352941176 0.407843137255 0.933333333333
AddColor lightslate 0.517647058824 0.439215686275 1.0
AddColor LightSlateBlue 0.517647058824 0.439215686275 1.0
AddColor mediumblue 0.0 0.0 0.803921568627
AddColor MediumBlue 0.0 0.0 0.803921568627
AddColor royalblue 0.254901960784 0.411764705882 0.882352941176
AddColor RoyalBlue 0.254901960784 0.411764705882 0.882352941176
AddColor blue 0.0 0.0 1.0
AddColor dodgerblue 0.117647058824 0.564705882353 1.0
AddColor DodgerBlue 0.117647058824 0.564705882353 1.0
AddColor deepsky 0.0 0.749019607843 1.0
AddColor DeepSkyBlue 0.0 0.749019607843 1.0
AddColor skyblue 0.529411764706 0.807843137255 0.921568627451
AddColor SkyBlue 0.529411764706 0.807843137255 0.921568627451
AddColor lightsky 0.529411764706 0.807843137255 0.980392156863
AddColor LightSkyBlue 0.529411764706 0.807843137255 0.980392156863
AddColor steelblue 0.274509803922 0.509803921569 0.705882352941
AddColor SteelBlue 0.274509803922 0.509803921569 0.705882352941
AddColor lightsteel 0.690196078431 0.76862745098 0.870588235294
AddColor LightSteelBlue 0.690196078431 0.76862745098 0.870588235294
AddColor lightblue 0.678431372549 0.847058823529 0.901960784314
AddColor LightBlue 0.678431372549 0.847058823529 0.901960784314
AddColor powderblue 0.690196078431 0.878431372549 0.901960784314
AddColor PowderBlue 0.690196078431 0.878431372549 0.901960784314
AddColor paleturquoise 0.686274509804 0.933333333333 0.933333333333
AddColor PaleTurquoise 0.686274509804 0.933333333333 0.933333333333
AddColor darkturquoise 0.0 0.807843137255 0.819607843137
AddColor DarkTurquoise 0.0 0.807843137255 0.819607843137
AddColor mediumturquoise 0.282352941176 0.819607843137 0.8
AddColor MediumTurquoise 0.282352941176 0.819607843137 0.8
AddColor turquoise 0.250980392157 0.878431372549 0.81568627451
AddColor cyan 0.0 1.0 1.0
AddColor lightcyan 0.878431372549 1.0 1.0
AddColor LightCyan 0.878431372549 1.0 1.0
AddColor cadetblue 0.372549019608 0.619607843137 0.627450980392
AddColor CadetBlue 0.372549019608 0.619607843137 0.627450980392
AddColor mediumaquamarine 0.4 0.803921568627 0.666666666667
AddColor MediumAquamarine 0.4 0.803921568627 0.666666666667
AddColor aquamarine 0.498039215686 1.0 0.83137254902
AddColor darkgreen 0.0 0.392156862745 0.0
AddColor DarkGreen 0.0 0.392156862745 0.0
AddColor darkolive 0.333333333333 0.419607843137 0.18431372549
AddColor DarkOliveGreen 0.333333333333 0.419607843137 0.18431372549
AddColor darksea 0.560784313725 0.737254901961 0.560784313725
AddColor DarkSeaGreen 0.560784313725 0.737254901961 0.560784313725
AddColor seagreen 0.180392156863 0.545098039216 0.341176470588
AddColor SeaGreen 0.180392156863 0.545098039216 0.341176470588
AddColor mediumsea 0.235294117647 0.701960784314 0.443137254902
AddColor MediumSeaGreen 0.235294117647 0.701960784314 0.443137254902
AddColor lightsea 0.125490196078 0.698039215686 0.666666666667
AddColor LightSeaGreen 0.125490196078 0.698039215686 0.666666666667
AddColor palegreen 0.596078431373 0.98431372549 0.596078431373
AddColor PaleGreen 0.596078431373 0.98431372549 0.596078431373
AddColor springgreen 0.0 1.0 0.498039215686
AddColor SpringGreen 0.0 1.0 0.498039215686
AddColor lawngreen 0.486274509804 0.988235294118 0.0
AddColor LawnGreen 0.486274509804 0.988235294118 0.0
AddColor green 0.0 1.0 0.0
AddColor chartreuse 0.498039215686 1.0 0.0
AddColor mediumspring 0.0 0.980392156863 0.603921568627
AddColor MediumSpringGreen 0.0 0.980392156863 0.603921568627
AddColor greenyellow 0.678431372549 1.0 0.18431372549
AddColor GreenYellow 0.678431372549 1.0 0.18431372549
AddColor limegreen 0.196078431373 0.803921568627 0.196078431373
AddColor LimeGreen 0.196078431373 0.803921568627 0.196078431373
AddColor yellowgreen 0.603921568627 0.803921568627 0.196078431373
AddColor YellowGreen 0.603921568627 0.803921568627 0.196078431373
AddColor forestgreen 0.133333333333 0.545098039216 0.133333333333
AddColor ForestGreen 0.133333333333 0.545098039216 0.133333333333
AddColor olivedrab 0.419607843137 0.556862745098 0.137254901961
AddColor OliveDrab 0.419607843137 0.556862745098 0.137254901961
AddColor darkkhaki 0.741176470588 0.717647058824 0.419607843137
AddColor DarkKhaki 0.741176470588 0.717647058824 0.419607843137
AddColor khaki 0.941176470588 0.901960784314 0.549019607843
AddColor palegoldenrod 0.933333333333 0.909803921569 0.666666666667
AddColor PaleGoldenrod 0.933333333333 0.909803921569 0.666666666667
AddColor lightgoldenrod 0.980392156863 0.980392156863 0.823529411765
AddColor LightGoldenrodYellow 0.980392156863 0.980392156863 0.823529411765
AddColor lightyellow 1.0 1.0 0.878431372549
AddColor LightYellow 1.0 1.0 0.878431372549
AddColor yellow 1.0 1.0 0.0
AddColor gold 1.0 0.843137254902 0.0
AddColor lightgoldenrod 0.933333333333 0.866666666667 0.509803921569
AddColor LightGoldenrod 0.933333333333 0.866666666667 0.509803921569
AddColor goldenrod 0.854901960784 0.647058823529 0.125490196078
AddColor darkgoldenrod 0.721568627451 0.525490196078 0.043137254902
AddColor DarkGoldenrod 0.721568627451 0.525490196078 0.043137254902
AddColor rosybrown 0.737254901961 0.560784313725 0.560784313725
AddColor RosyBrown 0.737254901961 0.560784313725 0.560784313725
AddColor indianred 0.803921568627 0.360784313725 0.360784313725
AddColor IndianRed 0.803921568627 0.360784313725 0.360784313725
AddColor saddlebrown 0.545098039216 0.270588235294 0.0745098039216
AddColor SaddleBrown 0.545098039216 0.270588235294 0.0745098039216
AddColor sienna 0.627450980392 0.321568627451 0.176470588235
AddColor peru 0.803921568627 0.521568627451 0.247058823529
AddColor burlywood 0.870588235294 0.721568627451 0.529411764706
AddColor beige 0.960784313725 0.960784313725 0.862745098039
AddColor wheat 0.960784313725 0.870588235294 0.701960784314
AddColor sandybrown 0.956862745098 0.643137254902 0.376470588235
AddColor SandyBrown 0.956862745098 0.643137254902 0.376470588235
AddColor tan 0.823529411765 0.705882352941 0.549019607843
AddColor chocolate 0.823529411765 0.411764705882 0.117647058824
AddColor firebrick 0.698039215686 0.133333333333 0.133333333333
AddColor brown 0.647058823529 0.164705882353 0.164705882353
AddColor darksalmon 0.913725490196 0.588235294118 0.478431372549
AddColor DarkSalmon 0.913725490196 0.588235294118 0.478431372549
AddColor salmon 0.980392156863 0.501960784314 0.447058823529
AddColor lightsalmon 1.0 0.627450980392 0.478431372549
AddColor LightSalmon 1.0 0.627450980392 0.478431372549
AddColor orange 1.0 0.647058823529 0.0
AddColor darkorange 1.0 0.549019607843 0.0
AddColor DarkOrange 1.0 0.549019607843 0.0
AddColor coral 1.0 0.498039215686 0.313725490196
AddColor lightcoral 0.941176470588 0.501960784314 0.501960784314
AddColor LightCoral 0.941176470588 0.501960784314 0.501960784314
AddColor tomato 1.0 0.388235294118 0.278431372549
AddColor orangered 1.0 0.270588235294 0.0
AddColor OrangeRed 1.0 0.270588235294 0.0
AddColor red 1.0 0.0 0.0
AddColor hotpink 1.0 0.411764705882 0.705882352941
AddColor HotPink 1.0 0.411764705882 0.705882352941
AddColor deeppink 1.0 0.078431372549 0.576470588235
AddColor DeepPink 1.0 0.078431372549 0.576470588235
AddColor pink 1.0 0.752941176471 0.796078431373
AddColor lightpink 1.0 0.713725490196 0.756862745098
AddColor LightPink 1.0 0.713725490196 0.756862745098
AddColor paleviolet 0.858823529412 0.439215686275 0.576470588235
AddColor PaleVioletRed 0.858823529412 0.439215686275 0.576470588235
AddColor maroon 0.690196078431 0.188235294118 0.376470588235
AddColor mediumviolet 0.780392156863 0.0823529411765 0.521568627451
AddColor MediumVioletRed 0.780392156863 0.0823529411765 0.521568627451
AddColor violetred 0.81568627451 0.125490196078 0.564705882353
AddColor VioletRed 0.81568627451 0.125490196078 0.564705882353
AddColor magenta 1.0 0.0 1.0
AddColor violet 0.933333333333 0.509803921569 0.933333333333
AddColor plum 0.866666666667 0.627450980392 0.866666666667
AddColor orchid 0.854901960784 0.439215686275 0.839215686275
AddColor mediumorchid 0.729411764706 0.333333333333 0.827450980392
AddColor MediumOrchid 0.729411764706 0.333333333333 0.827450980392
AddColor darkorchid 0.6 0.196078431373 0.8
AddColor DarkOrchid 0.6 0.196078431373 0.8
AddColor darkviolet 0.580392156863 0.0 0.827450980392
AddColor DarkViolet 0.580392156863 0.0 0.827450980392
AddColor blueviolet 0.541176470588 0.16862745098 0.886274509804
AddColor BlueViolet 0.541176470588 0.16862745098 0.886274509804
AddColor purple 0.627450980392 0.125490196078 0.941176470588
AddColor mediumpurple 0.576470588235 0.439215686275 0.858823529412
AddColor MediumPurple 0.576470588235 0.439215686275 0.858823529412
AddColor thistle 0.847058823529 0.749019607843 0.847058823529
AddColor snow1 1.0 0.980392156863 0.980392156863
AddColor snow2 0.933333333333 0.913725490196 0.913725490196
AddColor snow3 0.803921568627 0.788235294118 0.788235294118
AddColor snow4 0.545098039216 0.537254901961 0.537254901961
AddColor seashell1 1.0 0.960784313725 0.933333333333
AddColor seashell2 0.933333333333 0.898039215686 0.870588235294
AddColor seashell3 0.803921568627 0.772549019608 0.749019607843
AddColor seashell4 0.545098039216 0.525490196078 0.509803921569
AddColor AntiqueWhite1 1.0 0.937254901961 0.858823529412
AddColor AntiqueWhite2 0.933333333333 0.874509803922 0.8
AddColor AntiqueWhite3 0.803921568627 0.752941176471 0.690196078431
AddColor AntiqueWhite4 0.545098039216 0.513725490196 0.470588235294
AddColor bisque1 1.0 0.894117647059 0.76862745098
AddColor bisque2 0.933333333333 0.835294117647 0.717647058824
AddColor bisque3 0.803921568627 0.717647058824 0.619607843137
AddColor bisque4 0.545098039216 0.490196078431 0.419607843137
AddColor PeachPuff1 1.0 0.854901960784 0.725490196078
AddColor PeachPuff2 0.933333333333 0.796078431373 0.678431372549
AddColor PeachPuff3 0.803921568627 0.686274509804 0.58431372549
AddColor PeachPuff4 0.545098039216 0.466666666667 0.396078431373
AddColor NavajoWhite1 1.0 0.870588235294 0.678431372549
AddColor NavajoWhite2 0.933333333333 0.811764705882 0.63137254902
AddColor NavajoWhite3 0.803921568627 0.701960784314 0.545098039216
AddColor NavajoWhite4 0.545098039216 0.474509803922 0.36862745098
AddColor LemonChiffon1 1.0 0.980392156863 0.803921568627
AddColor LemonChiffon2 0.933333333333 0.913725490196 0.749019607843
AddColor LemonChiffon3 0.803921568627 0.788235294118 0.647058823529
AddColor LemonChiffon4 0.545098039216 0.537254901961 0.439215686275
AddColor cornsilk1 1.0 0.972549019608 0.862745098039
AddColor cornsilk2 0.933333333333 0.909803921569 0.803921568627
AddColor cornsilk3 0.803921568627 0.78431372549 0.694117647059
AddColor cornsilk4 0.545098039216 0.533333333333 0.470588235294
AddColor ivory1 1.0 1.0 0.941176470588
AddColor ivory2 0.933333333333 0.933333333333 0.878431372549
AddColor ivory3 0.803921568627 0.803921568627 0.756862745098
AddColor ivory4 0.545098039216 0.545098039216 0.513725490196
AddColor honeydew1 0.941176470588 1.0 0.941176470588
AddColor honeydew2 0.878431372549 0.933333333333 0.878431372549
AddColor honeydew3 0.756862745098 0.803921568627 0.756862745098
AddColor honeydew4 0.513725490196 0.545098039216 0.513725490196
AddColor LavenderBlush1 1.0 0.941176470588 0.960784313725
AddColor LavenderBlush2 0.933333333333 0.878431372549 0.898039215686
AddColor LavenderBlush3 0.803921568627 0.756862745098 0.772549019608
AddColor LavenderBlush4 0.545098039216 0.513725490196 0.525490196078
AddColor MistyRose1 1.0 0.894117647059 0.882352941176
AddColor MistyRose2 0.933333333333 0.835294117647 0.823529411765
AddColor MistyRose3 0.803921568627 0.717647058824 0.709803921569
AddColor MistyRose4 0.545098039216 0.490196078431 0.482352941176
AddColor azure1 0.941176470588 1.0 1.0
AddColor azure2 0.878431372549 0.933333333333 0.933333333333
AddColor azure3 0.756862745098 0.803921568627 0.803921568627
AddColor azure4 0.513725490196 0.545098039216 0.545098039216
AddColor SlateBlue1 0.513725490196 0.435294117647 1.0
AddColor SlateBlue2 0.478431372549 0.403921568627 0.933333333333
AddColor SlateBlue3 0.411764705882 0.349019607843 0.803921568627
AddColor SlateBlue4 0.278431372549 0.235294117647 0.545098039216
AddColor RoyalBlue1 0.282352941176 0.462745098039 1.0
AddColor RoyalBlue2 0.262745098039 0.43137254902 0.933333333333
AddColor RoyalBlue3 0.227450980392 0.372549019608 0.803921568627
AddColor RoyalBlue4 0.152941176471 0.250980392157 0.545098039216
AddColor blue1 0.0 0.0 1.0
AddColor blue2 0.0 0.0 0.933333333333
AddColor blue3 0.0 0.0 0.803921568627
AddColor blue4 0.0 0.0 0.545098039216
AddColor DodgerBlue1 0.117647058824 0.564705882353 1.0
AddColor DodgerBlue2 0.109803921569 0.525490196078 0.933333333333
AddColor DodgerBlue3 0.0941176470588 0.454901960784 0.803921568627
AddColor DodgerBlue4 0.0627450980392 0.305882352941 0.545098039216
AddColor SteelBlue1 0.388235294118 0.721568627451 1.0
AddColor SteelBlue2 0.360784313725 0.674509803922 0.933333333333
AddColor SteelBlue3 0.309803921569 0.580392156863 0.803921568627
AddColor SteelBlue4 0.211764705882 0.392156862745 0.545098039216
AddColor DeepSkyBlue1 0.0 0.749019607843 1.0
AddColor DeepSkyBlue2 0.0 0.698039215686 0.933333333333
AddColor DeepSkyBlue3 0.0 0.603921568627 0.803921568627
AddColor DeepSkyBlue4 0.0 0.407843137255 0.545098039216
AddColor SkyBlue1 0.529411764706 0.807843137255 1.0
AddColor SkyBlue2 0.494117647059 0.752941176471 0.933333333333
AddColor SkyBlue3 0.423529411765 0.650980392157 0.803921568627
AddColor SkyBlue4 0.290196078431 0.439215686275 0.545098039216
AddColor LightSkyBlue1 0.690196078431 0.886274509804 1.0
AddColor LightSkyBlue2 0.643137254902 0.827450980392 0.933333333333
AddColor LightSkyBlue3 0.552941176471 0.713725490196 0.803921568627
AddColor LightSkyBlue4 0.376470588235 0.482352941176 0.545098039216
AddColor SlateGray1 0.776470588235 0.886274509804 1.0
AddColor SlateGray2 0.725490196078 0.827450980392 0.933333333333
AddColor SlateGray3 0.623529411765 0.713725490196 0.803921568627
AddColor SlateGray4 0.423529411765 0.482352941176 0.545098039216
AddColor LightSteelBlue1 0.792156862745 0.882352941176 1.0
AddColor LightSteelBlue2 0.737254901961 0.823529411765 0.933333333333
AddColor LightSteelBlue3 0.635294117647 0.709803921569 0.803921568627
AddColor LightSteelBlue4 0.43137254902 0.482352941176 0.545098039216
AddColor LightBlue1 0.749019607843 0.937254901961 1.0
AddColor LightBlue2 0.698039215686 0.874509803922 0.933333333333
AddColor LightBlue3 0.603921568627 0.752941176471 0.803921568627
AddColor LightBlue4 0.407843137255 0.513725490196 0.545098039216
AddColor LightCyan1 0.878431372549 1.0 1.0
AddColor LightCyan2 0.819607843137 0.933333333333 0.933333333333
AddColor LightCyan3 0.705882352941 0.803921568627 0.803921568627
AddColor LightCyan4 0.478431372549 0.545098039216 0.545098039216
AddColor PaleTurquoise1 0.733333333333 1.0 1.0
AddColor PaleTurquoise2 0.682352941176 0.933333333333 0.933333333333
AddColor PaleTurquoise3 0.588235294118 0.803921568627 0.803921568627
AddColor PaleTurquoise4 0.4 0.545098039216 0.545098039216
AddColor CadetBlue1 0.596078431373 0.960784313725 1.0
AddColor CadetBlue2 0.556862745098 0.898039215686 0.933333333333
AddColor CadetBlue3 0.478431372549 0.772549019608 0.803921568627
AddColor CadetBlue4 0.325490196078 0.525490196078 0.545098039216
AddColor turquoise1 0.0 0.960784313725 1.0
AddColor turquoise2 0.0 0.898039215686 0.933333333333
AddColor turquoise3 0.0 0.772549019608 0.803921568627
AddColor turquoise4 0.0 0.525490196078 0.545098039216
AddColor cyan1 0.0 1.0 1.0
AddColor cyan2 0.0 0.933333333333 0.933333333333
AddColor cyan3 0.0 0.803921568627 0.803921568627
AddColor cyan4 0.0 0.545098039216 0.545098039216
AddColor DarkSlateGray1 0.592156862745 1.0 1.0
AddColor DarkSlateGray2 0.552941176471 0.933333333333 0.933333333333
AddColor DarkSlateGray3 0.474509803922 0.803921568627 0.803921568627
AddColor DarkSlateGray4 0.321568627451 0.545098039216 0.545098039216
AddColor aquamarine1 0.498039215686 1.0 0.83137254902
AddColor aquamarine2 0.462745098039 0.933333333333 0.776470588235
AddColor aquamarine3 0.4 0.803921568627 0.666666666667
AddColor aquamarine4 0.270588235294 0.545098039216 0.454901960784
AddColor DarkSeaGreen1 0.756862745098 1.0 0.756862745098
AddColor DarkSeaGreen2 0.705882352941 0.933333333333 0.705882352941
AddColor DarkSeaGreen3 0.607843137255 0.803921568627 0.607843137255
AddColor DarkSeaGreen4 0.411764705882 0.545098039216 0.411764705882
AddColor SeaGreen1 0.329411764706 1.0 0.623529411765
AddColor SeaGreen2 0.305882352941 0.933333333333 0.580392156863
AddColor SeaGreen3 0.262745098039 0.803921568627 0.501960784314
AddColor SeaGreen4 0.180392156863 0.545098039216 0.341176470588
AddColor PaleGreen1 0.603921568627 1.0 0.603921568627
AddColor PaleGreen2 0.564705882353 0.933333333333 0.564705882353
AddColor PaleGreen3 0.486274509804 0.803921568627 0.486274509804
AddColor PaleGreen4 0.329411764706 0.545098039216 0.329411764706
AddColor SpringGreen1 0.0 1.0 0.498039215686
AddColor SpringGreen2 0.0 0.933333333333 0.462745098039
AddColor SpringGreen3 0.0 0.803921568627 0.4
AddColor SpringGreen4 0.0 0.545098039216 0.270588235294
AddColor green1 0.0 1.0 0.0
AddColor green2 0.0 0.933333333333 0.0
AddColor green3 0.0 0.803921568627 0.0
AddColor green4 0.0 0.545098039216 0.0
AddColor chartreuse1 0.498039215686 1.0 0.0
AddColor chartreuse2 0.462745098039 0.933333333333 0.0
AddColor chartreuse3 0.4 0.803921568627 0.0
AddColor chartreuse4 0.270588235294 0.545098039216 0.0
AddColor OliveDrab1 0.752941176471 1.0 0.243137254902
AddColor OliveDrab2 0.701960784314 0.933333333333 0.227450980392
AddColor OliveDrab3 0.603921568627 0.803921568627 0.196078431373
AddColor OliveDrab4 0.411764705882 0.545098039216 0.133333333333
AddColor DarkOliveGreen1 0.792156862745 1.0 0.439215686275
AddColor DarkOliveGreen2 0.737254901961 0.933333333333 0.407843137255
AddColor DarkOliveGreen3 0.635294117647 0.803921568627 0.352941176471
AddColor DarkOliveGreen4 0.43137254902 0.545098039216 0.239215686275
AddColor khaki1 1.0 0.964705882353 0.560784313725
AddColor khaki2 0.933333333333 0.901960784314 0.521568627451
AddColor khaki3 0.803921568627 0.776470588235 0.450980392157
AddColor khaki4 0.545098039216 0.525490196078 0.305882352941
AddColor LightGoldenrod1 1.0 0.925490196078 0.545098039216
AddColor LightGoldenrod2 0.933333333333 0.862745098039 0.509803921569
AddColor LightGoldenrod3 0.803921568627 0.745098039216 0.439215686275
AddColor LightGoldenrod4 0.545098039216 0.505882352941 0.298039215686
AddColor LightYellow1 1.0 1.0 0.878431372549
AddColor LightYellow2 0.933333333333 0.933333333333 0.819607843137
AddColor LightYellow3 0.803921568627 0.803921568627 0.705882352941
AddColor LightYellow4 0.545098039216 0.545098039216 0.478431372549
AddColor yellow1 1.0 1.0 0.0
AddColor yellow2 0.933333333333 0.933333333333 0.0
AddColor yellow3 0.803921568627 0.803921568627 0.0
AddColor yellow4 0.545098039216 0.545098039216 0.0
AddColor gold1 1.0 0.843137254902 0.0
AddColor gold2 0.933333333333 0.788235294118 0.0
AddColor gold3 0.803921568627 0.678431372549 0.0
AddColor gold4 0.545098039216 0.458823529412 0.0
AddColor goldenrod1 1.0 0.756862745098 0.145098039216
AddColor goldenrod2 0.933333333333 0.705882352941 0.133333333333
AddColor goldenrod3 0.803921568627 0.607843137255 0.113725490196
AddColor goldenrod4 0.545098039216 0.411764705882 0.078431372549
AddColor DarkGoldenrod1 1.0 0.725490196078 0.0588235294118
AddColor DarkGoldenrod2 0.933333333333 0.678431372549 0.0549019607843
AddColor DarkGoldenrod3 0.803921568627 0.58431372549 0.0470588235294
AddColor DarkGoldenrod4 0.545098039216 0.396078431373 0.0313725490196
AddColor RosyBrown1 1.0 0.756862745098 0.756862745098
AddColor RosyBrown2 0.933333333333 0.705882352941 0.705882352941
AddColor RosyBrown3 0.803921568627 0.607843137255 0.607843137255
AddColor RosyBrown4 0.545098039216 0.411764705882 0.411764705882
AddColor IndianRed1 1.0 0.41568627451 0.41568627451
AddColor IndianRed2 0.933333333333 0.388235294118 0.388235294118
AddColor IndianRed3 0.803921568627 0.333333333333 0.333333333333
AddColor IndianRed4 0.545098039216 0.227450980392 0.227450980392
AddColor sienna1 1.0 0.509803921569 0.278431372549
AddColor sienna2 0.933333333333 0.474509803922 0.258823529412
AddColor sienna3 0.803921568627 0.407843137255 0.223529411765
AddColor sienna4 0.545098039216 0.278431372549 0.149019607843
AddColor burlywood1 1.0 0.827450980392 0.607843137255
AddColor burlywood2 0.933333333333 0.772549019608 0.56862745098
AddColor burlywood3 0.803921568627 0.666666666667 0.490196078431
AddColor burlywood4 0.545098039216 0.450980392157 0.333333333333
AddColor wheat1 1.0 0.905882352941 0.729411764706
AddColor wheat2 0.933333333333 0.847058823529 0.682352941176
AddColor wheat3 0.803921568627 0.729411764706 0.588235294118
AddColor wheat4 0.545098039216 0.494117647059 0.4
AddColor tan1 1.0 0.647058823529 0.309803921569
AddColor tan2 0.933333333333 0.603921568627 0.286274509804
AddColor tan3 0.803921568627 0.521568627451 0.247058823529
AddColor tan4 0.545098039216 0.352941176471 0.16862745098
AddColor chocolate1 1.0 0.498039215686 0.141176470588
AddColor chocolate2 0.933333333333 0.462745098039 0.129411764706
AddColor chocolate3 0.803921568627 0.4 0.113725490196
AddColor chocolate4 0.545098039216 0.270588235294 0.0745098039216
AddColor firebrick1 1.0 0.188235294118 0.188235294118
AddColor firebrick2 0.933333333333 0.172549019608 0.172549019608
AddColor firebrick3 0.803921568627 0.149019607843 0.149019607843
AddColor firebrick4 0.545098039216 0.101960784314 0.101960784314
AddColor brown1 1.0 0.250980392157 0.250980392157
AddColor brown2 0.933333333333 0.23137254902 0.23137254902
AddColor brown3 0.803921568627 0.2 0.2
AddColor brown4 0.545098039216 0.137254901961 0.137254901961
AddColor salmon1 1.0 0.549019607843 0.411764705882
AddColor salmon2 0.933333333333 0.509803921569 0.38431372549
AddColor salmon3 0.803921568627 0.439215686275 0.329411764706
AddColor salmon4 0.545098039216 0.298039215686 0.223529411765
AddColor LightSalmon1 1.0 0.627450980392 0.478431372549
AddColor LightSalmon2 0.933333333333 0.58431372549 0.447058823529
AddColor LightSalmon3 0.803921568627 0.505882352941 0.38431372549
AddColor LightSalmon4 0.545098039216 0.341176470588 0.258823529412
AddColor orange1 1.0 0.647058823529 0.0
AddColor orange2 0.933333333333 0.603921568627 0.0
AddColor orange3 0.803921568627 0.521568627451 0.0
AddColor orange4 0.545098039216 0.352941176471 0.0
AddColor DarkOrange1 1.0 0.498039215686 0.0
AddColor DarkOrange2 0.933333333333 0.462745098039 0.0
AddColor DarkOrange3 0.803921568627 0.4 0.0
AddColor DarkOrange4 0.545098039216 0.270588235294 0.0
AddColor coral1 1.0 0.447058823529 0.337254901961
AddColor coral2 0.933333333333 0.41568627451 0.313725490196
AddColor coral3 0.803921568627 0.356862745098 0.270588235294
AddColor coral4 0.545098039216 0.243137254902 0.18431372549
AddColor tomato1 1.0 0.388235294118 0.278431372549
AddColor tomato2 0.933333333333 0.360784313725 0.258823529412
AddColor tomato3 0.803921568627 0.309803921569 0.223529411765
AddColor tomato4 0.545098039216 0.211764705882 0.149019607843
AddColor OrangeRed1 1.0 0.270588235294 0.0
AddColor OrangeRed2 0.933333333333 0.250980392157 0.0
AddColor OrangeRed3 0.803921568627 0.21568627451 0.0
AddColor OrangeRed4 0.545098039216 0.145098039216 0.0
AddColor red1 1.0 0.0 0.0
AddColor red2 0.933333333333 0.0 0.0
AddColor red3 0.803921568627 0.0 0.0
AddColor red4 0.545098039216 0.0 0.0
AddColor DeepPink1 1.0 0.078431372549 0.576470588235
AddColor DeepPink2 0.933333333333 0.0705882352941 0.537254901961
AddColor DeepPink3 0.803921568627 0.0627450980392 0.462745098039
AddColor DeepPink4 0.545098039216 0.0392156862745 0.313725490196
AddColor HotPink1 1.0 0.43137254902 0.705882352941
AddColor HotPink2 0.933333333333 0.41568627451 0.654901960784
AddColor HotPink3 0.803921568627 0.376470588235 0.564705882353
AddColor HotPink4 0.545098039216 0.227450980392 0.38431372549
AddColor pink1 1.0 0.709803921569 0.772549019608
AddColor pink2 0.933333333333 0.662745098039 0.721568627451
AddColor pink3 0.803921568627 0.56862745098 0.619607843137
AddColor pink4 0.545098039216 0.388235294118 0.423529411765
AddColor LightPink1 1.0 0.682352941176 0.725490196078
AddColor LightPink2 0.933333333333 0.635294117647 0.678431372549
AddColor LightPink3 0.803921568627 0.549019607843 0.58431372549
AddColor LightPink4 0.545098039216 0.372549019608 0.396078431373
AddColor PaleVioletRed1 1.0 0.509803921569 0.670588235294
AddColor PaleVioletRed2 0.933333333333 0.474509803922 0.623529411765
AddColor PaleVioletRed3 0.803921568627 0.407843137255 0.537254901961
AddColor PaleVioletRed4 0.545098039216 0.278431372549 0.364705882353
AddColor maroon1 1.0 0.203921568627 0.701960784314
AddColor maroon2 0.933333333333 0.188235294118 0.654901960784
AddColor maroon3 0.803921568627 0.160784313725 0.564705882353
AddColor maroon4 0.545098039216 0.109803921569 0.38431372549
AddColor VioletRed1 1.0 0.243137254902 0.588235294118
AddColor VioletRed2 0.933333333333 0.227450980392 0.549019607843
AddColor VioletRed3 0.803921568627 0.196078431373 0.470588235294
AddColor VioletRed4 0.545098039216 0.133333333333 0.321568627451
AddColor magenta1 1.0 0.0 1.0
AddColor magenta2 0.933333333333 0.0 0.933333333333
AddColor magenta3 0.803921568627 0.0 0.803921568627
AddColor magenta4 0.545098039216 0.0 0.545098039216
AddColor orchid1 1.0 0.513725490196 0.980392156863
AddColor orchid2 0.933333333333 0.478431372549 0.913725490196
AddColor orchid3 0.803921568627 0.411764705882 0.788235294118
AddColor orchid4 0.545098039216 0.278431372549 0.537254901961
AddColor plum1 1.0 0.733333333333 1.0
AddColor plum2 0.933333333333 0.682352941176 0.933333333333
AddColor plum3 0.803921568627 0.588235294118 0.803921568627
AddColor plum4 0.545098039216 0.4 0.545098039216
AddColor MediumOrchid1 0.878431372549 0.4 1.0
AddColor MediumOrchid2 0.819607843137 0.372549019608 0.933333333333
AddColor MediumOrchid3 0.705882352941 0.321568627451 0.803921568627
AddColor MediumOrchid4 0.478431372549 0.21568627451 0.545098039216
AddColor DarkOrchid1 0.749019607843 0.243137254902 1.0
AddColor DarkOrchid2 0.698039215686 0.227450980392 0.933333333333
AddColor DarkOrchid3 0.603921568627 0.196078431373 0.803921568627
AddColor DarkOrchid4 0.407843137255 0.133333333333 0.545098039216
AddColor purple1 0.607843137255 0.188235294118 1.0
AddColor purple2 0.56862745098 0.172549019608 0.933333333333
AddColor purple3 0.490196078431 0.149019607843 0.803921568627
AddColor purple4 0.333333333333 0.101960784314 0.545098039216
AddColor MediumPurple1 0.670588235294 0.509803921569 1.0
AddColor MediumPurple2 0.623529411765 0.474509803922 0.933333333333
AddColor MediumPurple3 0.537254901961 0.407843137255 0.803921568627
AddColor MediumPurple4 0.364705882353 0.278431372549 0.545098039216
AddColor thistle1 1.0 0.882352941176 1.0
AddColor thistle2 0.933333333333 0.823529411765 0.933333333333
AddColor thistle3 0.803921568627 0.709803921569 0.803921568627
AddColor thistle4 0.545098039216 0.482352941176 0.545098039216
AddColor gray0 0.0 0.0 0.0
AddColor grey0 0.0 0.0 0.0
AddColor gray1 0.0117647058824 0.0117647058824 0.0117647058824
AddColor grey1 0.0117647058824 0.0117647058824 0.0117647058824
AddColor gray2 0.0196078431373 0.0196078431373 0.0196078431373
AddColor grey2 0.0196078431373 0.0196078431373 0.0196078431373
AddColor gray3 0.0313725490196 0.0313725490196 0.0313725490196
AddColor grey3 0.0313725490196 0.0313725490196 0.0313725490196
AddColor gray4 0.0392156862745 0.0392156862745 0.0392156862745
AddColor grey4 0.0392156862745 0.0392156862745 0.0392156862745
AddColor gray5 0.0509803921569 0.0509803921569 0.0509803921569
AddColor grey5 0.0509803921569 0.0509803921569 0.0509803921569
AddColor gray6 0.0588235294118 0.0588235294118 0.0588235294118
AddColor grey6 0.0588235294118 0.0588235294118 0.0588235294118
AddColor gray7 0.0705882352941 0.0705882352941 0.0705882352941
AddColor grey7 0.0705882352941 0.0705882352941 0.0705882352941
AddColor gray8 0.078431372549 0.078431372549 0.078431372549
AddColor grey8 0.078431372549 0.078431372549 0.078431372549
AddColor gray9 0.0901960784314 0.0901960784314 0.0901960784314
AddColor grey9 0.0901960784314 0.0901960784314 0.0901960784314
AddColor gray10 0.101960784314 0.101960784314 0.101960784314
AddColor grey10 0.101960784314 0.101960784314 0.101960784314
AddColor gray11 0.109803921569 0.109803921569 0.109803921569
AddColor grey11 0.109803921569 0.109803921569 0.109803921569
AddColor gray12 0.121568627451 0.121568627451 0.121568627451
AddColor grey12 0.121568627451 0.121568627451 0.121568627451
AddColor gray13 0.129411764706 0.129411764706 0.129411764706
AddColor grey13 0.129411764706 0.129411764706 0.129411764706
AddColor gray14 0.141176470588 0.141176470588 0.141176470588
AddColor grey14 0.141176470588 0.141176470588 0.141176470588
AddColor gray15 0.149019607843 0.149019607843 0.149019607843
AddColor grey15 0.149019607843 0.149019607843 0.149019607843
AddColor gray16 0.160784313725 0.160784313725 0.160784313725
AddColor grey16 0.160784313725 0.160784313725 0.160784313725
AddColor gray17 0.16862745098 0.16862745098 0.16862745098
AddColor grey17 0.16862745098 0.16862745098 0.16862745098
AddColor gray18 0.180392156863 0.180392156863 0.180392156863
AddColor grey18 0.180392156863 0.180392156863 0.180392156863
AddColor gray19 0.188235294118 0.188235294118 0.188235294118
AddColor grey19 0.188235294118 0.188235294118 0.188235294118
AddColor gray20 0.2 0.2 0.2
AddColor grey20 0.2 0.2 0.2
AddColor gray21 0.211764705882 0.211764705882 0.211764705882
AddColor grey21 0.211764705882 0.211764705882 0.211764705882
AddColor gray22 0.219607843137 0.219607843137 0.219607843137
AddColor grey22 0.219607843137 0.219607843137 0.219607843137
AddColor gray23 0.23137254902 0.23137254902 0.23137254902
AddColor grey23 0.23137254902 0.23137254902 0.23137254902
AddColor gray24 0.239215686275 0.239215686275 0.239215686275
AddColor grey24 0.239215686275 0.239215686275 0.239215686275
AddColor gray25 0.250980392157 0.250980392157 0.250980392157
AddColor grey25 0.250980392157 0.250980392157 0.250980392157
AddColor gray26 0.258823529412 0.258823529412 0.258823529412
AddColor grey26 0.258823529412 0.258823529412 0.258823529412
AddColor gray27 0.270588235294 0.270588235294 0.270588235294
AddColor grey27 0.270588235294 0.270588235294 0.270588235294
AddColor gray28 0.278431372549 0.278431372549 0.278431372549
AddColor grey28 0.278431372549 0.278431372549 0.278431372549
AddColor gray29 0.290196078431 0.290196078431 0.290196078431
AddColor grey29 0.290196078431 0.290196078431 0.290196078431
AddColor gray30 0.301960784314 0.301960784314 0.301960784314
AddColor grey30 0.301960784314 0.301960784314 0.301960784314
AddColor gray31 0.309803921569 0.309803921569 0.309803921569
AddColor grey31 0.309803921569 0.309803921569 0.309803921569
AddColor gray32 0.321568627451 0.321568627451 0.321568627451
AddColor grey32 0.321568627451 0.321568627451 0.321568627451
AddColor gray33 0.329411764706 0.329411764706 0.329411764706
AddColor grey33 0.329411764706 0.329411764706 0.329411764706
AddColor gray34 0.341176470588 0.341176470588 0.341176470588
AddColor grey34 0.341176470588 0.341176470588 0.341176470588
AddColor gray35 0.349019607843 0.349019607843 0.349019607843
AddColor grey35 0.349019607843 0.349019607843 0.349019607843
AddColor gray36 0.360784313725 0.360784313725 0.360784313725
AddColor grey36 0.360784313725 0.360784313725 0.360784313725
AddColor gray37 0.36862745098 0.36862745098 0.36862745098
AddColor grey37 0.36862745098 0.36862745098 0.36862745098
AddColor gray38 0.380392156863 0.380392156863 0.380392156863
AddColor grey38 0.380392156863 0.380392156863 0.380392156863
AddColor gray39 0.388235294118 0.388235294118 0.388235294118
AddColor grey39 0.388235294118 0.388235294118 0.388235294118
AddColor gray40 0.4 0.4 0.4
AddColor grey40 0.4 0.4 0.4
AddColor gray41 0.411764705882 0.411764705882 0.411764705882
AddColor grey41 0.411764705882 0.411764705882 0.411764705882
AddColor gray42 0.419607843137 0.419607843137 0.419607843137
AddColor grey42 0.419607843137 0.419607843137 0.419607843137
AddColor gray43 0.43137254902 0.43137254902 0.43137254902
AddColor grey43 0.43137254902 0.43137254902 0.43137254902
AddColor gray44 0.439215686275 0.439215686275 0.439215686275
AddColor grey44 0.439215686275 0.439215686275 0.439215686275
AddColor gray45 0.450980392157 0.450980392157 0.450980392157
AddColor grey45 0.450980392157 0.450980392157 0.450980392157
AddColor gray46 0.458823529412 0.458823529412 0.458823529412
AddColor grey46 0.458823529412 0.458823529412 0.458823529412
AddColor gray47 0.470588235294 0.470588235294 0.470588235294
AddColor grey47 0.470588235294 0.470588235294 0.470588235294
AddColor gray48 0.478431372549 0.478431372549 0.478431372549
AddColor grey48 0.478431372549 0.478431372549 0.478431372549
AddColor gray49 0.490196078431 0.490196078431 0.490196078431
AddColor grey49 0.490196078431 0.490196078431 0.490196078431
AddColor gray50 0.498039215686 0.498039215686 0.498039215686
AddColor grey50 0.498039215686 0.498039215686 0.498039215686
AddColor gray51 0.509803921569 0.509803921569 0.509803921569
AddColor grey51 0.509803921569 0.509803921569 0.509803921569
AddColor gray52 0.521568627451 0.521568627451 0.521568627451
AddColor grey52 0.521568627451 0.521568627451 0.521568627451
AddColor gray53 0.529411764706 0.529411764706 0.529411764706
AddColor grey53 0.529411764706 0.529411764706 0.529411764706
AddColor gray54 0.541176470588 0.541176470588 0.541176470588
AddColor grey54 0.541176470588 0.541176470588 0.541176470588
AddColor gray55 0.549019607843 0.549019607843 0.549019607843
AddColor grey55 0.549019607843 0.549019607843 0.549019607843
AddColor gray56 0.560784313725 0.560784313725 0.560784313725
AddColor grey56 0.560784313725 0.560784313725 0.560784313725
AddColor gray57 0.56862745098 0.56862745098 0.56862745098
AddColor grey57 0.56862745098 0.56862745098 0.56862745098
AddColor gray58 0.580392156863 0.580392156863 0.580392156863
AddColor grey58 0.580392156863 0.580392156863 0.580392156863
AddColor gray59 0.588235294118 0.588235294118 0.588235294118
AddColor grey59 0.588235294118 0.588235294118 0.588235294118
AddColor gray60 0.6 0.6 0.6
AddColor grey60 0.6 0.6 0.6
AddColor gray61 0.611764705882 0.611764705882 0.611764705882
AddColor grey61 0.611764705882 0.611764705882 0.611764705882
AddColor gray62 0.619607843137 0.619607843137 0.619607843137
AddColor grey62 0.619607843137 0.619607843137 0.619607843137
AddColor gray63 0.63137254902 0.63137254902 0.63137254902
AddColor grey63 0.63137254902 0.63137254902 0.63137254902
AddColor gray64 0.639215686275 0.639215686275 0.639215686275
AddColor grey64 0.639215686275 0.639215686275 0.639215686275
AddColor gray65 0.650980392157 0.650980392157 0.650980392157
AddColor grey65 0.650980392157 0.650980392157 0.650980392157
AddColor gray66 0.658823529412 0.658823529412 0.658823529412
AddColor grey66 0.658823529412 0.658823529412 0.658823529412
AddColor gray67 0.670588235294 0.670588235294 0.670588235294
AddColor grey67 0.670588235294 0.670588235294 0.670588235294
AddColor gray68 0.678431372549 0.678431372549 0.678431372549
AddColor grey68 0.678431372549 0.678431372549 0.678431372549
AddColor gray69 0.690196078431 0.690196078431 0.690196078431
AddColor grey69 0.690196078431 0.690196078431 0.690196078431
AddColor gray70 0.701960784314 0.701960784314 0.701960784314
AddColor grey70 0.701960784314 0.701960784314 0.701960784314
AddColor gray71 0.709803921569 0.709803921569 0.709803921569
AddColor grey71 0.709803921569 0.709803921569 0.709803921569
AddColor gray72 0.721568627451 0.721568627451 0.721568627451
AddColor grey72 0.721568627451 0.721568627451 0.721568627451
AddColor gray73 0.729411764706 0.729411764706 0.729411764706
AddColor grey73 0.729411764706 0.729411764706 0.729411764706
AddColor gray74 0.741176470588 0.741176470588 0.741176470588
AddColor grey74 0.741176470588 0.741176470588 0.741176470588
AddColor gray75 0.749019607843 0.749019607843 0.749019607843
AddColor grey75 0.749019607843 0.749019607843 0.749019607843
AddColor gray76 0.760784313725 0.760784313725 0.760784313725
AddColor grey76 0.760784313725 0.760784313725 0.760784313725
AddColor gray77 0.76862745098 0.76862745098 0.76862745098
AddColor grey77 0.76862745098 0.76862745098 0.76862745098
AddColor gray78 0.780392156863 0.780392156863 0.780392156863
AddColor grey78 0.780392156863 0.780392156863 0.780392156863
AddColor gray79 0.788235294118 0.788235294118 0.788235294118
AddColor grey79 0.788235294118 0.788235294118 0.788235294118
AddColor gray80 0.8 0.8 0.8
AddColor grey80 0.8 0.8 0.8
AddColor gray81 0.811764705882 0.811764705882 0.811764705882
AddColor grey81 0.811764705882 0.811764705882 0.811764705882
AddColor gray82 0.819607843137 0.819607843137 0.819607843137
AddColor grey82 0.819607843137 0.819607843137 0.819607843137
AddColor gray83 0.83137254902 0.83137254902 0.83137254902
AddColor grey83 0.83137254902 0.83137254902 0.83137254902
AddColor gray84 0.839215686275 0.839215686275 0.839215686275
AddColor grey84 0.839215686275 0.839215686275 0.839215686275
AddColor gray85 0.850980392157 0.850980392157 0.850980392157
AddColor grey85 0.850980392157 0.850980392157 0.850980392157
AddColor gray86 0.858823529412 0.858823529412 0.858823529412
AddColor grey86 0.858823529412 0.858823529412 0.858823529412
AddColor gray87 0.870588235294 0.870588235294 0.870588235294
AddColor grey87 0.870588235294 0.870588235294 0.870588235294
AddColor gray88 0.878431372549 0.878431372549 0.878431372549
AddColor grey88 0.878431372549 0.878431372549 0.878431372549
AddColor gray89 0.890196078431 0.890196078431 0.890196078431
AddColor grey89 0.890196078431 0.890196078431 0.890196078431
AddColor gray90 0.898039215686 0.898039215686 0.898039215686
AddColor grey90 0.898039215686 0.898039215686 0.898039215686
AddColor gray91 0.909803921569 0.909803921569 0.909803921569
AddColor grey91 0.909803921569 0.909803921569 0.909803921569
AddColor gray92 0.921568627451 0.921568627451 0.921568627451
AddColor grey92 0.921568627451 0.921568627451 0.921568627451
AddColor gray93 0.929411764706 0.929411764706 0.929411764706
AddColor grey93 0.929411764706 0.929411764706 0.929411764706
AddColor gray94 0.941176470588 0.941176470588 0.941176470588
AddColor grey94 0.941176470588 0.941176470588 0.941176470588
AddColor gray95 0.949019607843 0.949019607843 0.949019607843
AddColor grey95 0.949019607843 0.949019607843 0.949019607843
AddColor gray96 0.960784313725 0.960784313725 0.960784313725
AddColor grey96 0.960784313725 0.960784313725 0.960784313725
AddColor gray97 0.96862745098 0.96862745098 0.96862745098
AddColor grey97 0.96862745098 0.96862745098 0.96862745098
AddColor gray98 0.980392156863 0.980392156863 0.980392156863
AddColor grey98 0.980392156863 0.980392156863 0.980392156863
AddColor gray99 0.988235294118 0.988235294118 0.988235294118
AddColor grey99 0.988235294118 0.988235294118 0.988235294118
AddColor gray100 1.0 1.0 1.0
AddColor grey100 1.0 1.0 1.0
AddColor darkgrey 0.662745098039 0.662745098039 0.662745098039
AddColor DarkGrey 0.662745098039 0.662745098039 0.662745098039
AddColor darkgray 0.662745098039 0.662745098039 0.662745098039
AddColor DarkGray 0.662745098039 0.662745098039 0.662745098039
AddColor darkblue 0.0 0.0 0.545098039216
AddColor DarkBlue 0.0 0.0 0.545098039216
AddColor darkcyan 0.0 0.545098039216 0.545098039216
AddColor DarkCyan 0.0 0.545098039216 0.545098039216
AddColor darkmagenta 0.545098039216 0.0 0.545098039216
AddColor DarkMagenta 0.545098039216 0.0 0.545098039216
AddColor darkred 0.545098039216 0.0 0.0
AddColor DarkRed 0.545098039216 0.0 0.0
AddColor lightgreen 0.564705882353 0.933333333333 0.564705882353
AddColor LightGreen 0.564705882353 0.933333333333 0.564705882353

set list [lsort $list]

foreach name $list {
	puts $fd "\t\{ \"$name\", \{ $Colors($name) \} \},"
	}

puts $fd "\n\t\};\n"

puts $fd "#define NUMBER_OF_COLORS sizeof(colors)/sizeof(ColorEntry)\n"

close $fd

set fd [open colorlist.tcl w]

puts $fd "# --- colorlist.tcl --- This is the list of colors in the Fltk database"
puts $fd "\nset ColorList { "

foreach name $list {
	puts $fd "\t$name"
	}

puts $fd "\t}\n"

close $fd

puts "Generated [llength $list] colors!"

