#!/bin/sh
# \
exec fltkwish "$0" ${1+"$@"}
#
# --- embed.tcl --- Demonstration of an embedded Tk window in an Fltk top level
#
# Copyright (C) I.B.Findleton, 2001.  All Rights Reserved.
#
# This is a rather basic and bizarre example of how one might go about embedding
# a Tk widget tree inside an Fltk Toplevel window. While it does work, it is
# not, to my eye, a pretty sight.
#
# If you have a fast machine, uncomment the following line to see an example
# of Tk wrapped in OpenGL...

# Scheme shiny

# Create an Fltk toplevel and put a button in it that can be used to dismiss
# the application. This just demonstrates that the Fltk widget set is present.

Toplevel t -w 500 -h 500 -relief sunkenframe

Button t.b1 -text Dismiss -command Quit

# The <Resize> event is sent to widgets when a resize occurs. Here I bind
# a handler to the event that will manage the geometry of the Tk widgets

Bind t <Resize> { HandleResize %W .child }

# The root window is hidden by default, so create another toplevel to play with.

set child [toplevel .child]

# Create a frame and put a Tk canvas inside the frame. Then draw something
# in the canvas. Note that the Tk commands co-exist happly with the Fltk
# commands, as do the widget windows.

set f [frame $child.frame -bd 2 -relief ridge]

set c [canvas $f.canvas -width 400 -height 400]

$c create rectangle 50 50 300 200 -fill red 

pack $c -side top -fill both -expand yes

pack $f

# Cleanup when the window is closed

proc Quit {} {

	exit
	}


# When a resize event happens, this function will move the Tk widget accordingly

proc HandleResize { win child } {

# Get the Fltk root widget geometry

	set fltk_geometry [$win get -x -y -w -h]

# Compute a new location for the Tk child

	set x [expr [lindex $fltk_geometry 0] + 20]
	set y [expr [lindex $fltk_geometry 1] + 40]
	set w [expr [lindex $fltk_geometry 2] - 40]
	set h [expr [lindex $fltk_geometry 3] - 80]

# Position the Tk child..

	if { [catch { wm geometry $child [format "%dx%d+%d+%d" $w $h $x $y] } reason] } {
		puts "Geometry failed because : $reason"
		}

	raise $child
	update
}

Show t

 
