#!/bin/sh
# \
exec fltkwish "$0" -- ${1+"$@"}
#
# --- help.tcl --- Generate a help page for the Help command
#
# Copyright(C) I.B.Findleton, 2001. All Rights Reserved
#
# Start a page
#
proc StartPage { fd title opts } {

	puts $fd "<html>"
	puts $fd "<head><title>$title</title></head>"
	puts $fd "<body $opts>"
	}
	
# Write a header

proc WriteHeader { fd level text } {

	puts $fd <h$level>$text</h$level>

	}
	
# A paragraph

proc Paragraph { fd text } {

	puts $fd "<p>$text</p>"
	
	}

# An unnumbered list of items

proc UnnumberedLinkList { fd list } {

	puts $fd "<ul>"

	foreach item $list {
		set name [string range $item 1 end]
		puts $fd "<li><a href=help_$name.html>$name</a></li>"
		}

	puts $fd </ul>
	}
	
# An unnumbered list of items

proc UnnumberedList { fd list } {

	puts $fd "<ul>"

	foreach item $list {
		puts $fd "<li>$item</li>"
		}

	puts $fd </ul>
	}
	
# End a page

proc EndPage { fd { ref "" } } {

	puts $fd </body>

	puts $fd </html>
	}

# Set the background color of the page

set BodyOptions "bgcolor=\"#FFFF00\""

# Get the list of help topics that are available

set list [lindex [split [Help] :] 2]

# Create a file for the main page

set fd [open help.html w]

StartPage $fd "Fltk Help Topics" $BodyOptions

WriteHeader $fd 1 "Fltk Help Topics"

Paragraph $fd "The following topics are available..."

UnnumberedLinkList $fd $list

EndPage $fd

close $fd

# Filter the values

proc FilterValues { vals } {

	if { [string first : $vals] != -1 } {
		set list [split $vals :]
		set vals [lindex $list [expr [llength $list] - 1]]
		}
		
	regsub -all {<+} $vals {} vals
	regsub -all {>+} $vals {} vals
	
	return $vals
	}
	
# Create the pages for each of the help topics

foreach item $list {

	set name [string range $item 1 end]
	
	puts $item
	
	set fd [open "help_$name.html" w]

	StartPage $fd "Help for $name" $BodyOptions
	WriteHeader $fd 1 $name
	Paragraph $fd "The following values are valid..."
	set vals [FilterValues [Help $item]]
	UnnumberedList $fd $vals
	EndPage $fd

	close $fd

	}


