#!/bin/sh
# \
exec fltkwish "$0" -- ${1+"$@"}

# --- image.tcl --- Test harness for the Image widget

# Copyright(C) I.B.Findleton, 2001. All Rights Reserved.

# This command will clean any old instances of the root widget and
# get rid of any children as well.

catch { Destroy t }

# This is the file name of a test image, a very pretty girl!

set Data(ImageName) [GetFileName "Choose the image file to display:" *.jpg,*.gif,*.bmp,*.png ../scripts/images/ashley.gif]

# Create a top level window to hold the widgets.

Toplevel t -w 500 -align left; 

# The following Package holds a Label widget and an Image widget packed
# together vertically.

Package t.p -orientation vertical

# This widget will be automatically resized in the horizontal direction
# by the Package to be the same width as the Image widget.

Label t.p.l -text [file tail $Data(ImageName)] -relief raised

# The Image widget will show the image centered by default. Note the
# use of the "frame" style of relief. This avoids flicker when drawing
# the widget.

set Data(Image) [Image t.p.i -f $Data(ImageName) -relief raisedframe]

# Some variables for monitoring things

set Data(Location) ""
set Data(Flip) 0
set Data(Mirror) 0
set Data(Centered) 0
set Data(Mono) 0
set Data(ColorValue) ""

set Data(Xorg) 0
set Data(Yorg) 0

# This procedure will update the display items when the mouse moves
# over the image.

proc PrintColor { w x y } {

	global Data

# Mouse input is relative to the containing window, so, make
# the value relative to the widget itself.

	incr x -[$w get -x]
	incr y -[$w get -y]

# The image may not be displayed at the (0,0) location. Get the
# image inset values and adjust the locations to be image relative
 
	incr x -[$w get -imagex]
	incr y -[$w get -imagey]

# Grab the color of the pixel at the image location. It is returned
# a a list of 3 values. Since only 1 location is specified, the color
# is the first element of the returned list.

	set color [lindex [$w getpixel $x,$y] 0]

# Update the display of the mouse coordinates. This widget is linked
# to a global variable for automatic update.

	set Data(Location) $x,$y

# Decode the color components and create a parameter for the color
# display output widget...

	set r [lindex $color 0]
	set g [lindex $color 1]
	set b [lindex $color 2]

	set Data(ColorValue) "$r,$g,$b"

	$Data(Color) config -bg $r,$g,$b 

	}

# Configure the image using the image options

proc ConfigureImage {} {

	global Data

	$Data(Image) config -imagex $Data(Xorg) -imagey $Data(Yorg) -flip $Data(Flip) -mirror $Data(Mirror) -centered $Data(Centered) -mono $Data(Mono)

#	puts "Configure x $Data(Xorg) y $Data(Yorg)"
	}

# Bind an event handler to the mouse motion event on the widget. 

Bind t.p.i <Motion> { PrintColor %W %x %y }

# Ceate a button that will get rid of the window

Button t.exit -x 220 -text Quit -command exit

# Some simple outputs to display things

Output t.loc -x 370 -y 60 -width 100 -variable Data(Location) -label Mouse -align left
set Data(Color) [Output t.color -x 370 -width 100 -label Color -align left]
Output t.colorvalue -x 370 -y 35 -label Value -align left -variable Data(ColorValue)

# Option management buttons. They are contained in a package to make
# alignment and size automatic. The option database is used to set up
# a configuration for the buttons.

Package t.f -x 220 -y 50 -o vertical -w 100

Option add LightButton.width 100
Option add LightButton.relief flat
Option add LightButton.align inside,left
Option add LightButton.type toggle
Option add LightButton.selectioncolor red

# The following command scripts demonstrate the use of the name of configurable
# parameters as substitutable elements of the scripts.
 
LightButton t.f.fill -text "Flip Image" -command { set Data(Flip) %value ; ConfigureImage } 
LightButton t.f.mirror -text "Mirror Image" -command { set Data(Mirror) %value ; ConfigureImage }
LightButton t.f.center -text "Center Image" -command { set Data(Centered) %value ; ConfigureImage }
LightButton t.f.mono -text "Mono Image" -command { set Data(Mono) %value ; ConfigureImage }

# Add some scroll bars for configuring the image location

Scrollbar t.x -x 370 -y 100 -w 100 -label "X Origin" -max 0 \
			-min [expr [t.p.i get -w] - [t.p.i get -imagewidth]] \
			-align left -variable Data(Xorg) -command ConfigureImage
Scrollbar t.y -x 370 -y 130 -w 100 -label "Y Origin" -max 0 \
			-min [expr [t.p.i get -h] - [t.p.i get -imageheight]] \
			-align left -variable Data(Yorg) -command ConfigureImage

Bind Button <Enter> { %W set -fg 238,88,55 }
Bind Button <Leave> { %W set -fg black }

# Initialize the state of the image

ConfigureImage

# Show the entire window

Show t

# Note that Wm commands will only work is the target window is mapped.

Wm title t "Image Widget Demonstration"


