#!/bin/sh
# \
exec fltkwish "$0" ${1+"$@"}
#
# --- imagebtn.tcl --- Test harness for an image button
#
# Copyright(C) I.B.Findleton, 2001. All Rights Reserved
#
set Data(ImagePath) images/weather
set Data(ImageList) [glob $Data(ImagePath)/*.bmp]
set Data(Current) Sunny
set Data(Forecast) Cloudy

# Get the weather descriptions from the image names...lazy, lazy, lazy!

foreach i $Data(ImageList) {
	set name [file split $i]
	set len [llength $name]
	set Data($i) [join [split [file rootname [lindex $name [expr $len - 1]]] _] " "]
	}

# Choose a name at random from the list

proc RandomElement { list } {

	return [lindex $list [expr int(rand() * [llength $list])]]
	}

Toplevel t -w 350
#
# This procedure will let you know what the weather is...
#
proc Weather { w } {

	global Data

	set i [RandomElement $Data(ImageList)]
	$w config -upimage $i
	set Data(Current) $Data($i)
	puts "Image $i Description $Data($i)"
	}

# Here is a weather forecast...

proc Forecast { w } {

	global Data

	if { [catch { $w config -upimage [set i [RandomElement $Data(ImageList)]] } reason] } {
		puts "$i is bad because $reason" 
	 } else {
		puts "$i"
		}

	set Data(Forecast) $Data([$w get -upimage])
}

# Test the button functionality

proc TextFunction { w } {

	set v [$w get -value]

	puts "Value $v"

	switch -exact -- $v {

"0"		{ puts "Its cloudy!" }
"1"		{ puts "Its raining!" }
		} ;# End of cases
	}
#
# Configure the labels  using the option database
#
Option add Label.relief flat
Option add Label.width 150
Option add Label.align left,inside

# This package will hold an image button, a label and an output to
# show the current weather.

set p1 [Package t.p1 -padding 5 -h 60]
#
# Create an image button with 1 image. Shrink the button to the image
# size of the up image. Add a command to print a cute message.
#
Label $p1.l1 -text "Shrink Wrapped Image Button"

ImageButton $p1.b -command { Weather %W }  \
		 -up $Data(ImagePath)/Sunny.bmp \
		-shrink true

Text $p1.o1 -variable Data(Current) -width 95 -h 60
# 
# The package that holds a label and the forecast generator
#
set p2 [Package t.p2 -padding 5 -y 75]
#
Label $p2.l2  -text "Image and Text Button"
#
# Another package to hold the forecast generator and its output
#
set p3 [Package $p2.p3 -orientation vertical -padding 5 -w 165]
#
# Here is a button that uses an image to implement something like a
# LightButton. The button press changes the image.
#
ImageButton $p3.b1 -centered false -imagerelief sunken \
			-up $Data(ImagePath)/Cloudy.bmp \
			-ix 2 -iy 2 -iw 20 -ih 20 -h 60 \
			-font helv,bold,italic -align right,inside \
			-fontsize 12 -foreground red -command { Forecast %W } \
			-label "Make Forecast" -type toggle
#
# Here is a text box that displays the results
#
Text $p3.o1 -variable Data(Forecast) -h 60
#
set p4 [Package t.p4 -padding 5 -y 210]

# And a button to get rid of the demo. All that is needed is to press
# the enter key....
#
Label $p4.l4 -text "Return Button"
#
ReturnButton $p4.b3 -command exit -w 165 -text "Press Enter to Dismiss"
#
Show t

Wm title t "Image Button Demonstration"


