#!/bin/sh
# \
exec fltkwish "$0" ${1+"$@"}
#
# --- imageloop.tcl --- Test harness for the Iterator widget
#
set PROGRAM ImageLoop
set VERSION V1.00

Scheme modern -bg silver

# Load a file

proc LoadFile { w name } {

	global PROGRAM VERSION
	global where l
	
	$w set -f $name
	Wm title t "$PROGRAM $VERSION : $name"
	
	t.all.progress set -value [lsearch $l $where]
	}
	
set path [GetInput "Enter a path name" "images/weather"]
set extension [GetInput "Enter the file extension (e.g. gif or jpg)" "gif"]

set rate 100

# Get the list of files to display

if { [catch { glob $path/*.$extension } l] } {
	puts "No files found in $path/*.$extension"
	exit
	}
	
set l [lsort $l]
set files [llength $l]
	
# Change the animation rate

proc ChangeRate { w } {

	global rate
	
	$w.ahead set -rate $rate
	$w.reverse set -rate $rate
	
	}

Option add Iterator.list l
Option add Iterator.w 50
Option add Iterator.variable where
		
Destroy t

set f [Package t.all -orientation vertical]

Image $f.text -w 600 -h 400

ProgressBar $f.progress -limit [expr $files - 1] -h 5 -indicator orangered3 \
		-percent false -relief raised

set f1 [Package $f.actions -orientation horizontal]

Iterator $f1.reverse -auto true -command "LoadFile $f.text %value" \
		-rate $rate -label @<< -type toggle -autostop true \
		-forward false -tooltip "Animate in reverse"

# Here is an iterator that steps backwards through the loop

Iterator $f1.back -command "LoadFile $f.text %value" -label @< \
	-forward false -tooltip "Show previous image"

# This simple button stops the loop

Button $f1.stop -command "$f1.ahead stop ; $f1.reverse stop" -label "@||" -w 50 \
	-tooltip "Stop the current animation loop"

# Here is a simple iterator that steps forward through the list

Iterator $f1.fwd -command "LoadFile $f.text %value" -label @> \
		-tooltip "Show the next image"

# This button will automatically repeat its command when pressed on a
# time delay defined by the rate option. The repeat cycle will continue
# until the button is pressed again.
#
Iterator $f1.ahead -auto true -command "LoadFile $f.text %value" \
		 -rate $rate -label @>> -type toggle -autostop true \
		 -tooltip "Animate forward"
		 
Label $f1.label -w 50 -label Files -relief raised		 
Value $f1.files -w 50 -variable files -relief sunken \
		-tooltip "Number of files in the loop"
		 
Slider $f1.speed -variable rate -min 10 -max 1000 -value 100 -step 10 -command "ChangeRate $f1" \
		 -w -100 -tooltip "Move slider to change the speed of animation"
		
Value $f1.rate -variable rate -w 50 -bg white -relief sunken 
		 
Button $f1.quit -command Exit -label Exit -tooltip "Quit this application"

Show [Center t]

Wm title t "Iterator Test"

$f1.fwd current 0
