#!/bin/sh
# \
exec fltkwish "$0" ${1+"$@"}
#
# --- marks.tcl --- Test harness for the image marker
#
# Copyright (C) I.B.Findleton, 2001. All Rights Reserved
#
set Data(Mouse) ""
set Data(Last) ""
set Data(Loc) ""

catch { Destroy t }
#
# Create a widget that can hold an image
#
Image t.t -w 300 -h 250 -relief raised \
	-tooltip "Click to select the closest mark.."

# Set up some default options for a LabeledText widget

Option add LabeledText.labelalign right,inside
Option add LabeledText.x 350
Option add LabeledText.align center

Option add Button.x 450

# Some things for viewing what is happening...

LabeledText t.loc -variable Data(Mouse) -label "Mouse Location"
LabeledText t.what -y +20 -variable Data(Last) -label "Current Item"
LabeledText t.where -y +40 -variable Data(Loc) -label "Item Location"

Button t.quit -y +100 -text Dismiss -command Exit
#
# Put some marks on the widget. No image is used because this only
# tests mark functionality
#
t.t add low -at 20,40
t.t add high -at 100,100
t.t add low -at 20,180
t.t add high -at 200,50
#
# Select the closest mark to the location of the mouse
#
proc Mouse { w x y } {

	global Data

	set item [$w closest $x,$y]

#	puts "$w $x $y $item"

	if { $Data(Last) != "" } {
		$w itemconfig $Data(Last) -color black
		}

	$w itemconfig $item -color red

	set Data(Last) $item
	set Data(Loc) [$w query $item -x],[$w query $item -y]
	}
#
# Display the current mouse location
#
proc Motion { x y } {

	global Data

	set Data(Mouse) "$x,$y"
	}
#
Bind t.t <ButtonPress> { Mouse %W %x %y }
Bind t.t <Motion> { Motion %x %y }
#
# Display the main window 
#
Show t
#
Wm title t "Test harness for the image marking functions"


