#!/bin/sh
# \
exec fltkwish "$0" ${1+"$@"}

# --- menu.tcl --- Harness for testing the menu functions

# Copyright(C) I.B.Findleton, 2000. All Rights Reserved.

# Let's use the OpenGL rendering scheme

package require Fltk

# If you want to see this in GL rendering, uncomment the following line

#Scheme set shiny

# Establish some default options for the menus. Here the colors used for the menu
# are the ones defined by the current color scheme. On a Windows computer, this
# will be the one set by the control panel.

Option clear Menu

Option add Menu.font helv,italic
Option add Menu.fontsize 12
Option add Menu.relief flat
Option add Menu.foreground systemmenutext
Option add Menu.background systemmenu

Option clear MenuEntry

Option add MenuEntry.width 12

Option add Toplevel.background systemappworkspace

catch { unset Data }

Destroy root
Toplevel root -title "Menu Demonstration" -autosize false

# Create a menu that looks like a typical application menu

set Data(Menu) [set m [Menu root.menu]]

# The File menu. Note the use of the "terminator" menu item which is used
# to signal the end of a cascaded sub-menu. The & signs generate the usual
# underlined letter form of a shortcut hint, along with the keyboard shortcut.

$m add cascade -label &File
$m add command -label &New -command { FileNew }
$m add command -label &Open -command { FileOpen }
$m add command -label &Save -state inactive -command { FileSave }
$m add command -label Save&As -state inactive -command { FileSaveAs }
$m add separator
$m add command -label E&xit -command { exit }
$m add terminator

# The Edit menu

$m add cascade -label &Edit
$m add command -label &Copy -command { MenuProc %W }
$m add command -label Cu&t -command { MenuProc %W }
$m add command -label &Paste -command { MenuProc %W }
$m add terminator

# A Help button

$m add command -label &Help -command { MenuProc %W }

# Display the main window

Show root

set Data(Dirty) 0

# This just prints a message

proc MenuProc { w } {

	puts stdout "[$w cget -label]"
	}

# Create a new file

proc FileNew {} {

	global Data

   set Data(Dirty) 1
   }

# Open a file

proc FileOpen {} {

	global Data

   set Data(Dirty) 1
   }

# Save the file using the current name

proc FileSave {} {

	global Data

   set Data(Dirty) 0
	}

# Save the file using a name provided by the user

proc FileSaveAs {} {

	global Data

   set Data(Dirty) 0
   }

# Get a state for the menu item

proc GetState { state } {

	if { $state } { return "active" } else { return "inactive" }

   }

# A little proc to make testing easier

proc IsEqual { a b { true 1 } { false 0 } } {

	if { $a == $b } { return $true } else { return $false }
}

# Set the state of menu items according to the file data state

proc ConfigureMenu { name1 name2 op } {

	global Data

   set m $Data(Menu)

   $m entryconfig 1 -state [GetState [IsEqual $Data(Dirty) 1 0 1]]
   $m entryconfig 2 -state [GetState [IsEqual $Data(Dirty) 1 0 1]]
   $m entryconfig 3 -state [GetState $Data(Dirty)]
   $m entryconfig 4 -state [GetState $Data(Dirty)]
   $m entryconfig 5 -state [GetState [IsEqual $Data(Dirty) 1 0 1]]
}

# Use the variable trace mechanism to set the state of the menu items

trace variable Data(Dirty) w ConfigureMenu


