#!/bin/sh
# \
exec fltkwish "$0" ${1+"$@"}
#
# --- obsdata.tcl --- Inspect the observations database
#
package require Tclgdbm
#
set Data(DefaultRoot) /database/weather.data
set Data(Database) $Data(DefaultRoot)/station.observations.gdbm
set Data(Station) ""
set Data(Record) ""
set Data(RecordLabel) ""
set Data(Choice) ""
set Data(Delete) 0

# Get the list of keys for a specified name

proc GetKeys { name } {

	global Data
	
	set db [gdbm open $Data(Database) r]

	set list [lsort [gdbm list $db -filter $name]]

	gdbm close $db

	return $list
	}

# Handle a button press in the list box

proc HandleChoice { w } {

	global Data

	set db [gdbm open $Data(Database) r]
	set key "$Data(Station)*[clock scan $Data(Choice)]"
	set Data(RecordLabel) "Observation for $Data(Station) at $Data(Choice)"

	set Data(Record) "[join [split [gdbm fetch $db $key] *] \n]"

	gdbm close $db

	set Data(Delete) 1

	}

# Handle input from the widget

proc HandleInput { w } {

	global Data

	LoadKeys
	}

# Load the keys from the database

proc LoadKeys {} {

	global Data

	set Data(Delete) 0
	set Data(Record) ""
	set Data(RecordLabel) ""

	$Data(List) clear

	set list [GetKeys $Data(Station)]

	foreach item $list {
		set parts [split $item *]
		$Data(List) add "[clock format [lindex $parts 1] -gmt 1]"
		}
	}

# Delete a record from the database

proc DeleteRecord {} {

	global Data

	set key "$Data(Station)*[clock scan $Data(Choice)]

	set db [n $Data(Database) rw]

	gdbm delete $db $key

	gdbm close $db

	LoadKeys
	}
	
Destroy t

set f [Package t.all -orientation vertical]

set f0 [Package $f.station -orientation horizontal -relief ridge -w 600]

#Label $f0.label -text "Station Name" -relief raised -align inside,left
#Input $f0.input -variable Data(Station) -command { HandleInput %W }

LabeledInput $f0.input -labelrelief raised -label "Station Name" -variable Data(Station) -command { HandleInput %W }

Button $f0.delete -command { DeleteRecord } -text Delete -statevariable Data(Delete)
Button $f0.quit -label "Dismiss" -command { Exit }

set f1 [Package $f.data -orientation horizontal]

set f2 [Package $f1.listing -orientation vertical]
Label $f2.label -label "Valid Time" -relief raised
set Data(List) [Listbox $f2.list -height 300 -width 200 -variable Data(Choice) \
		-command { HandleChoice %W } ]

set f3 [Package $f1.record -orientation vertical]
Label $f3.label -variable Data(RecordLabel) -relief raised
Text $f3.text -height 300 -width 400 -variable Data(Record)

Show t
