#!/bin/sh
proc CheckForPackage { name { version "" } } {
global tcl_platform
set site "http://pages.infinit.net/cclients/software.htm"
if { [string length $version] != 0 } {
set result [catch { package require $name $version } reason]
} else {
set result [catch { package require $name } reason]
}
if { $result } {
puts stderr "Did not get package $name $version : $reason"
puts stderr "This script requires the $name $version package!"
puts stderr "Get it at $site"
if { $tcl_platform(platform) == "unix" } {
catch { exec $Data(Browser) $site & } 
} else {
catch { exec start $site & }
}
exit
}
return $reason
}
CheckForPackage TclUtils
CheckForPackage httpcopy
CheckForPackage Fltk 0.4
if { $tcl_platform(platform) == "unix" } {
set Data(DefaultWidgets) 6	;} else {
set Data(DefaultWidgets) 4
}
set Data(Scheme) "Image -f $Fltk(Library)/images/clouds.jpg"
if { [catch { package require Tclgdbm } reason] } {
set Data(HasGdbm) 0
} else {
set Data(HasGdbm) 1
}
set Maps(Verbose) 0
set Data(Station) YUL,YMX,YHU,YOW,YGK,YSC,YYZ,YQB,KBOS,KJFK
set Data(BaseURL) weatheroffice.ec.gc.ca
set Data(Script) forecast/city_e.html
set Data(Client,Canada) ?
set Data(Client,USA) ?
set Data(Token) {}
set Data(Browser) mozilla
if { $tcl_platform(platform) == "unix" } {
set host [lindex [split [exec hostname] .] 0]
} else {
set host windows
}
switch -exact -- $host {
ganymede	{
set Data(DefaultRoot) /public/Database/weather.data
}
io	-
invicta	{
set Data(DefaultRoot) /database/weather.data
}
windows	{
set Data(DefaultRoot) "c:"
}
default	{	set Data(DefaultRoot) $env(HOME)
}
} ;set Data(LogFile) $Data(DefaultRoot)/station.log
set Data(Images) $Fltk(Library)/images/weather
if { $host == "invicta" } {
set Data(Images) /source/Fltk-0.3/scripts/images/weather
}
set Data(DefaultMode) 0	;set Data(DefaultUnits) ""	;if { $Data(HasGdbm) } {
set Data(Database) $Data(DefaultRoot)/station.observations.gdbm
} else {
}
set Data(MissingValue) "???"	;set Data(GMT) 1	;set Data(HasNext) 0	;set Data(HasPrev) 0	;set Data(HistoryLimit) 24	;set VarList { Temperature Pressure DewPoint WindSpeed WindDirection}
proc DisplayHelp {} {
set Help "\nThe format of the command line is:\n\n \
			\tstnplot ?-a? ?scheme? ?-s? ?stations? ?-m? ?mode? ?-u? ?units?\n \
			where -s or -stations specifies a comma seperated list of stations to watch\n \
			\t\t?-v? ?verbose? ?-w? ?widgets? ?-h? ?history?\n \
			\t\t?-g? ?gmt? ?-d? ?database? ?-??\n\n \
			\t-m or -mode specifies the mode to display the data (plot or depiction)\n \
			\t-u or -units specifies the units to use (imperial or metric)\n \
			\t-v or -verbose specifies whether download information is displayed (yes or no)\n \
			\t-w or -widgets specifies the number of widgets to display (default 4)\n \
			\t-d or -database specifies the database to use for history\n \
			\t-g or -gmt specifies whether time is local or GMT\n \
			\t-h or -history specifies the number of hours of history to keep\n \
			\t-a or -appearance specifies the scheme to use\n \
			\t-?	or -help displays this help message.\n"
puts $Help
Exit
}
foreach { option value } $argv {
switch -exact -- [string tolower $option] {
"-a"	-
"-appearance"	{	set Data(Scheme) $value	}
"-d"	-
"-database"	{	set Data(Database) $value
}
"-g"	-
"-gmt"	{	set Data(GMT) [IsEqual [string tolower $value] yes 1 0]
}
"-m"	-
"-mode"	{	set Data(DefaultMode) [IsEqual [string tolower $value] plot 0 1]
}	
"-s"	-
"-station"	{	set Data(Station) [string toupper $value] }
"-u"	-
"-units"	{	set Data(DefaultUnits) [IsEqual [string tolower $value] imperial "&Unit=I" ""]
}
"-v"	-
"-verbose"	{	set Maps(Verbose) [IsEqual [string tolower $value] "yes"]
}
"-w"	-
"-widgets"	{	set Data(DefaultWidgets) $value
}
"-h"	-
"-history"	{	set Data(HistoryLimit) $value
}
"-?"	-
"-help"	{	DisplayHelp
}
default	{	puts "Option $option is not supported!"
DisplayHelp
}
} ;} ;eval "Scheme $Data(Scheme)"
set SkyConditions {
{	"Mostly Cloudy"	"Cloudy"	6	}
{	"Sunny"	"Sunny"	0	}
{	"Clear"	"Clear"	0	}
{	"Overcast"	"Cloudy"	8	}
{ 	"Mainly Clear"	"Cloudy_with_clear_periods"	2	}
{ 	"Mainly Sunny"	"Sunny_with_cloudy_periods"	2	}
{	"Cloudy"	"Cloudy" 	4	}
}
proc FindSkyCondition { station str hour } {
global SkyConditions Data
foreach entry $SkyConditions {
if { [string first "[lindex $entry 0]" $str] != -1 } {
return [lindex $entry 2]
}
}
return "-1"
}
set Obstructions {
{	"light rainshower"	"RW-" 	"Showers"	}
{	"moderate rainshower"	"RW"	"Rainy"	}
{	"heavy rainshower"	"RW+"	"Rainy"	}
{	"rainshower"	"RW-"	"Showers"	}
{	"light snowshower"	"SW-"	"Cloudy_with_snow"	}
{	"moderate snowshower"	"SW"	"Cloudy_with_snow"	}
{	"heavy snowshower"	"SW+"	"Snowing"	}
{	"snowshower"	"SW-"	"Cloudy_with_snow"	}
{	"snow grains"	"SG"	"Cloudy_with_snow"	}
{	"moderate freezing rain" "ZR" "Freezing_rain"	}
{	"heavy freezing rain"	"ZR+" "Freezing_rain"	}
{	"freezing rain"	"ZR-" "Freezing_rain"	}
{	"light rain"	"R-"	"Rainy"	}
{	"moderate rain"	"R"	"Rainy"	}
{	"heavy rain"	"R+"	"Rainy"	}
{	"rain"	"R-"	"Rainy"	}
{	"precipitation"	"R-"	"Rainy"	}	
{	"light snow"	"S-"	"Snowing"	}
{	"moderate snow"	"S"	"Snowing"	}
{	"heavy snow"	"S+"	"Snowing"	}
{	"drifting snow"	"DS"	"Blowing_snow" }
{	"blowing snow"	"BS"	"Blowing_snow" }
{	"snow"	"S-"	"Snowing"	}
{	"light drizzle"	"L-"	"Drizzle"	}
{	"moderate drizzle"	"L"	"Drizzle"	}
{	"freezing drizzle"	"ZL-"	"Freezing_rain"	}
{	"drizzle"	"L-"	"drizzle"	}
{	"heavy thunderstorm" 	"TRW+" "Thundershowers"	}
{	"thunderstorm"	"TRW"	"Thundershowers"	}
{	"thunder"	"T"	"Thundershowers"	}
{	"haze"	"H"	"Haze"	}
{	"smoke"	"K"	"Smoke"	}
{	"mist"	"M"	"Mist"	}
{	"fog"	"F"	"Foggy"	}
{	"dust"	"D"	"Dust" }
}
proc FindObstructions { station str hour } {
global Obstructions Data
set result ""
set list [split $str ,]
foreach item $list {
foreach entry $Obstructions {
if { [regexp -nocase "[lindex $entry 0]" $item] != 0 } {
append result [lindex $entry 1]
break
}
}
}
return $result
}
set Data(Names) [list "Temperature" "Pressure" "Visibility" "Humidity" \
"DewPoint" "WindDirection" "WindSpeed" "WindGusts" \
"WindChill" "Humidex" "Tendency" "CurrentWeather" "Image" \
"TendencyCode" "MslPressure" "CloudAmount" "ObsTime" \
"VisLocation" "MaxTemp" "MinTemp" "MeanTemp" "Sunrise" "Sunset" \
"Moonrise" "Moonset" "Precip" "Icon" ]
set Data(Update) 1
proc SaveDataToFile { what where } {
set fd [open $where w]
if { $fd != "" } {
puts $fd $what
close $fd
}
return $what
}
proc MakeQuery { name } {
global Data
set query "$Data(BaseURL)/$Data(Script)"
switch -exact -- [string index $name 0] {
"K"	{
set query "$query$Data(Client,USA)$name"
} 
"C"	{
set name [string range $name 1 end]
set query "$query$Data(Client,Canada)$name"
}
default	{	
set query "$query$Data(Client,Canada)$name"
}
} ;return "$query$Data(DefaultUnits)"
}
proc LoadStationData { name } {
global Data tcl_platform
if { $tcl_platform(platform) == "unix" } {
set Data(FileName) /tmp/$name[clock seconds].txt
} else {
set Data(FileName) $Data(DefaultRoot)/$name.txt
}
if { [catch { ::http::copy [MakeQuery $name] $Data(FileName) } reason] } {
puts stderr $reason
return 0
}
return 1
}
proc GetObservedData { name } {
set fd [open $name r]
if { $fd == "" } {
puts stderr "Failed to open file $name!"
return ""
}
set txt [read $fd]
close $fd
return [CleanHTMLBlock $txt]
}
proc CleanHTMLBlock { txt } {
regsub -all {Current(.*)Currently} $txt {} txt
regsub -all {These icons(.*)World Wide Web Site.} $txt {} txt
regsub -all {<IMG+|<img+} $txt {IMG} txt ;regsub -all {<([^>])+>} $txt {} txt ;regsub -all -line {^([[:space:]])*\n} $txt {} txt 
regsub -all {\t+} $txt { } txt ;regsub -all { +} $txt { } txt ;regsub -all -lineanchor {^( *)} $txt {} txt	 ;regsub -all -line ^ $txt {} txt ;regsub -all -line :\n^ $txt {: } txt	 ;regsub -all -line {Temp(.?)\n^} $txt {Temp: } txt
regsub -all -line {\n(.?)C } $txt {C} txt
regsub -all -lineanchor {$\nat \n} $txt {at } txt ;regsub -all {&nbsp;} $txt { } txt
return $txt
}
set Data(ExtractNumbers) {([-0123456789.%])+}
proc GetNumberValue { str { width 4 } } {
global Data
if { ! [regexp -all $Data(ExtractNumbers) $str value] } {
set value $Data(MissingValue)
}
set len [string length $value]
while { $len < $width } {
set value " $value"
incr len
}
return $value
}
proc MakeTimeCode { str } {
set list [split [string trim $str]]
if { [lindex $list 5] == "UTC" || [lindex $list 5] == "GMT" } {
set n "[lindex $list 0] [lindex $list 1] [lindex $list 2] [lindex $list 4] [lindex $list 5]"
} else {
set n "[lindex $list 0] [lindex $list 1] [lindex $list 2] [lindex $list 4] [lindex $list 5] [lindex $list 6]"
} 	
regsub -all {[.,]+} $n {} n
return [clock scan $n -gmt 1]
}
proc ConvertWindSpeed { metric } {
return $metric
}
proc ParseWind { station str hour } {
global Data
set dir [string trim $str]
set len [string len $dir]
set i 0
while { $i < $len } {
if { [string first [string index $dir $i] "0123456789"] != -1 } {
set len $i
break
}
incr i
}
set dir [string range $dir 0 [expr $len - 1]] 
set Data($station,WindDirection,$hour) [FindDirection $dir]
if { [string first gust $str] != -1 } {
regexp -all $Data(ExtractNumbers) $str Data($station,WindSpeed,$hour) Data($station,WindGusts,$hour)
set Data($station,WindSpeed,$hour) [ConvertWindSpeed $Data($station,WindSpeed,$hour)]
set Data($station,WindGusts,$hour) [ConvertWindSpeed $Data($station,WindGusts,$hour)]
} else {
regexp -all $Data(ExtractNumbers) $str Data($station,WindSpeed,$hour)
set Data($station,WindSpeed,$hour) [ConvertWindSpeed $Data($station,WindSpeed,$hour)]
}
}
proc Pad { value { len 3 } { with 0 } } {
set length [string length $value]
while { $length < $len } {
set value $with$value
incr length
}
return $value 
}
proc Millibars { value } {
global Data
set value [string trimleft $value 0]
if { $value != $Data(MissingValue) } {
set value [expr int($value * 10)]
return [expr $value % 1000]
} else {
return $value
}
}
proc ParseData { station txt } {
global Data
set Data(ObsTime) $Data(MissingValue)
set HasNormals [set Data([MakeKey $station HasNormals $Data(ObsTime)]) 0]
set idx 0
foreach line [set list [split $txt \n]] {
if { [string length $line] != 0 } {
set line [string trim $line]
set parts [split $line :]
switch -exact -- [string trim [lindex $parts 0]] {
"Observed on"	{	set Data(ValidTime) [lindex $parts 1]:[lindex $parts 2]
set Data(ObsTime) [MakeTimeCode $Data(ValidTime)]
set Data($station,Image,$Data(ObsTime)) ""
set Data($station,ObsTime,$Data(ObsTime)) $Data(ObsTime)
}
"Temp."	{	regsub {&deg;+} [lindex $parts 1] {} tmp
set tmp "$tmp [lindex $parts 2]"
set Data([MakeKey $station Temperature $Data(ObsTime)]) [GetNumberValue $tmp]
}
"Pressure"	{	set tmp [FudgePressure [GetNumberValue [lindex $parts 1]]]
set Data([MakeKey $station MslPressure $Data(ObsTime)]) $tmp
set Data([MakeKey $station Pressure $Data(ObsTime)]) [Pad [Millibars $tmp]]
}
"Visibility"	{	set Data([MakeKey $station Visibility $Data(ObsTime)]) [GetNumberValue [lindex $parts 1]]
set Data([MakeKey $station VisLocation $Data(ObsTime)]) ""
}
"DewPoint"	{	regsub {&deg;+} [lindex $parts 1] {} tmp
set tmp "$tmp [lindex $parts 2]"
set Data([MakeKey $station DewPoint $Data(ObsTime)]) [GetNumberValue $tmp]
}
"Humidity"	{	set Data([MakeKey $station Humidity $Data(ObsTime)]) [GetNumberValue [lindex $parts 1]]
}
"Wind"	{	ParseWind $station [lindex $parts 1] $Data(ObsTime)
}
"WindChill"	{	set Data([MakeKey $station WindChill $Data(ObsTime)]) [GetNumberValue [lindex $parts 1]]
}
"Humidex"	{	set Data([MakeKey $station Humidex $Data(ObsTime)]) [GetNumberValue [lindex $parts 1]]
}
"Normal"	{	set HasNormals [set Data([MakeKey $station HasNormals $Data(ObsTime)]) 1]	}
"Max Temp"	{	regsub {&deg;+} [lindex $parts 1] {} tmp
if { $HasNormals } {
set Data([MakeKey $station MaxTemp $Data(ObsTime)]) [GetNumberValue $tmp]
} else {
set Data([MakeKey $station MaxHier $Data(ObsTime)]) [GetNumberValue $tmp]
}
}
"Min Temp"	{	regsub {&deg;+} [lindex $parts 1] {} tmp
if { $HasNormals } {
set Data([MakeKey $station MinTemp $Data(ObsTime)]) [GetNumberValue $tmp]
} else {
set Data([MakeKey $station MinHier $Data(ObsTime)]) [GetNumberValue $tmp]
}
}
"Mean Temp"	{	regsub {&deg;+} [lindex $parts 1] {} tmp
if { $HasNormals } {
set Data([MakeKey $station MeanTemp $Data(ObsTime)]) [GetNumberValue $tmp]
} else {
set Data([MakeKey $station MeanHier $Data(ObsTime)]) [GetNumberValue $tmp]
}
}
"Moonrise"	{	set Data([MakeKey $station Moonrise $Data(ObsTime)]) [lindex $list [expr $idx + 1]]
}
"Moonset"	{	set Data([MakeKey $station Moonset $Data(ObsTime)]) [lindex $list [expr $idx + 1]]
}
"Sunrise"	{	set Data([MakeKey $station Sunrise $Data(ObsTime)]) [lindex $list [expr $idx + 1]]
}
"Sunset"	{	set Data([MakeKey $station Sunset $Data(ObsTime)]) [lindex $list [expr $idx + 1]]
}
"Precip. Total"	{	set Data([MakeKey $station Precip $Data(ObsTime)]) [lindex $list [expr $idx + 1]]
}
default	{	if { [string length [string trim $line]] } { } 
}
} ;}
incr idx	
}
if { $Data(ObsTime) == $Data(MissingValue) } {
return 0
}
set Data($station,Latest) $Data(ObsTime)
set Data([MakeKey $station Tendency $Data(ObsTime)]) $Data(MissingValue)
ComputePressureTendency $station $Data(ObsTime)
ComposeCurrentWeather $station $txt $Data(ObsTime)
set Data([MakeKey $station CloudAmount $Data(ObsTime)]) [FindSkyCondition \
$station $Data([MakeKey $station CurrentWeather $Data(ObsTime)]) $Data(ObsTime)]
return 1
}
proc GetTendencyCode { change } {
if { $change < 0 } { 
return 1 
} else {
if { $change > 0 } {
return 3
} else {
return 2
}
}
}
proc FudgePressure { p } {
if { $p == "???" } { return $p }
return [expr $p + rand()/10.0]
}
proc PressureChange { station t1 t2 } {
global Data
set p1 [GetData $station MslPressure $t1]
set p2 [GetData $station MslPressure $t2]
if { $p1 == $Data(MissingValue) || $p2 == $Data(MissingValue) } {
puts "Missing value for $station p1 = $p1 p2 = $p2"
return 0
}
return [expr $p1 - $p2]
}
proc ComputePressureTendency { station hour } {
global Data
if { [HasDataForField $station Tendency $hour] } { return }
set previous [expr $hour - (3 * 3600)]
if { [HasDataForField $station MslPressure $hour] } {
if { [HasDataForField $station MslPressure $previous] } {
set change [PressureChange $station $hour $previous]
set Data([MakeKey $station Tendency $hour]) [expr int($change * 100)]
} else {
puts "No history data for $station at [clock format $previous -gmt 1]"
}
set tm1 [expr $hour - 3600]
set tm2 [expr $tm1 - 3600]
if [HasDataForField $station MslPressure $tm2] {
if [HasDataForField $station MslPressure $tm1] { 
set change [PressureChange $station $tm1 $tm2]
set key [MakeKey $station TendencyCode $hour]
set Data($key) [GetTendencyCode $change]
set change [PressureChange $station $hour $tm1]
set Data($key) [expr ($Data($key) << 2) | [GetTendencyCode $change]]
}
} 
} else {
puts "Data for $station at [clock format $hour -gmt 1] is missing"
}
}
proc MoveFile { from to } {
if { [catch { file copy $from $to } reason] } {
puts "Failed to move file $from to $to because : $reason"
}
}
proc DownloadIconImage { icon name } {
global Data Maps tcl_platform
regsub -all { } $name {_} filename
set filename $filename.gif
set result 0
if { $tcl_platform(platform) == "unix" } {
set tmpfile tmp[clock seconds].gif
} else {
set tmpfile tmp.gif
}
if { ! [file exists $Data(Images)/$filename] } {
if { [catch { ::http::copy $Data(BaseURL)/$icon $tmpfile } reason] } {
puts "Failed to get $icon because : $reason"
} else {
if { $Maps(IsImage) } {
MoveFile $tmpfile $Data(Images)/$filename
if { ! [file exists $Data(Images)/$icon] } {
MoveFile $tmpfile $Data(Images)/$icon
}
set result 1
} else {
puts "$icon not found on server!"
}
}
catch { file delete $tmpfile } reason	
} else {
set result 1
}
return $result	
}
proc ComposeCurrentWeather { station txt hour } {
global Data
set list [split $txt \n]
set idx [lsearch -glob $list "*Observed on*"]
if { $idx != -1 } {
set icon [lindex [split [lindex $list [incr idx]] ] 1]
set icon [string range $icon 6 end]
regsub -all {\"+} $icon {} Data([MakeKey $station Icon $hour])
set Data([MakeKey $station CurrentWeather $hour]) [string trim [lindex $list [incr idx 1]]]
Log "Icon $Data($station,Icon,$hour) -> $Data($station,CurrentWeather,$hour)"
if { [DownloadIconImage $Data($station,Icon,$hour) $Data($station,CurrentWeather,$hour)] == 0 } {
puts "No icon for $Data($station,CurrentWeather,$hour) at $station at $hour!"
img $Data(Images)/weathericons/29.gif
} else {
set img $Data(Images)/$Data($station,Icon,$hour)
}
set Data($station,Image,$hour) $img
if { [GetData $station CurrentWeather $hour] != "" } {
set len [expr [string length [GetData $station CurrentWeather $hour]] * 3]
set Data([MakeKey $station WxLocation $hour]) -$len
}
if { [GetData $station Visibility $hour] != $Data(MissingValue) } {
set wx [FindObstructions $station [string tolower [GetData $station CurrentWeather $hour]] $hour]
if { $wx != "" } {
set key [MakeKey $station Visibility $hour]
set Data($key) "$Data($key)$wx"
set Data([MakeKey $station VisLocation $hour]) "sp -[expr (4 * [string length $wx])] +0"
}
}
}	
}
proc DrawSkyCover { station hour } {
global Data
set result "home bg white fill 1 "
switch -exact -- $Data($station,CloudAmount,$hour) {
"0"	{	append result "bg blue arc 5 0 360 "
}
"2"	{	append result "arc 5 0 90 " 
}
"4"	{	append result "arc 5 0 180 "
}
"6"	{	append result "arc 5 0 270 "
}
"8"	{	append result "arc 5 0 360 "
}
"-1"	{	append result "pc 40 arc 5 0 360 "
}
} ;append result "( hm pc black sp -5 +0 rt 90 fd 10 hm sp +0 +5 fd 10 )"
return $result
}
proc Log { msg } {
global Data
set fd [open $Data(LogFile) a+]
if { $fd != "" } {
puts $fd "[clock format [clock seconds] ] : $msg"
close $fd
}
}
proc LogMissingFields { station hour } {
global Data
set str ""
foreach name $Data(Names) {
if { [GetData $station $name $hour] == $Data(MissingValue) } {
append str "$name "
}
}
Log "Missing Items for $station $str"
}
proc MakeKey { station name hour } {
return "$station,$name,$hour"
}
proc HasDataForField { station name hour } {
global Data
set key [MakeKey $station $name $hour]
if [info exists Data($key)] {
if { $Data($key) != $Data(MissingValue) } {
return 1
}
}
return 0
}
proc SaveData { station name hour value } {
global Data
set key [MakeKey $station $name $hour]
set Data($key) $value
}
proc GetData { station name hour } {
global Data
set key [MakeKey $station $name $hour]
if [info exists Data($key)] {
return $Data($key)
} else {
return $Data(MissingValue)
}
}
proc StoreDataHistory { station hour } {
global Data
set record ""
foreach name $Data(Names) {
if { [GetData $station $name $hour] != $Data(MissingValue) } {
if { [string length $record] != 0 } {
append record "*$name=[GetData $station $name $hour]"
} else {
set record "$name=[GetData $station $name $hour]"
}
}
}
if { $Data(HasGdbm) } {
if [file exists $Data(Database)] {
set db [gdbm open $Data(Database) rw] 
} else {	
set db [gdbm open $Data(Database) rwc]
}
gdbm store $db "$station*$hour" "$record"
gdbm close $db
} else {
}
}
proc UpdateStationList { stationlist } {
global Data
set Data(Update) 0
if { $Data(Token) != "" } {
after cancel $Data(Token)
}
foreach station [split $stationlist ,] {
set windows [Windows list]
set idx [lsearch -glob $windows *$station.plot]
if { $idx != -1 } {
if { [catch { UpdateStation [lindex [Windows list] $idx] $station } reason] } {
puts "Failed to update station $station : $reason"
}
} else {
puts "Can't find window for station $station in $windows!"
}
}
set now [clock seconds]
set delay [expr (int(($now / 3600) * 3600 + 900)) - $now]
if { $delay < 0 } { set delay [expr 30 * 60] }
set Data(Token) [after [expr $delay * 1000] "UpdateStationList $stationlist"]
set Data(Update) 1
}
proc UpdateStation { w station } {
global Data Model
set Data($station,Update) 1
if { [LoadStationData $station] } {
set data [GetObservedData $Data(FileName)]
SaveDataToFile $data "/tmp/$station.txt"
if { [ParseData $station $data] == 0 } {
Log "Data not available for $station"
set Data($station,Model) $Model(NotAvailable)
set Data(Update) 1
set Data($station,Update) 0
catch { file delete $Data(FileName) }
return 1
}
StoreDataHistory $station $Data(ObsTime)
catch { file delete $Data(FileName) }
} else {
Log "Failed to get data for $station!"
set Data($station,Model) $Model(MissingData)
set Data(Update) 1
set Data($station,Update) 0
catch { file delete $Data(FileName) }
return 1
}
catch { file delete $Data(FileName) }
if [catch { BuildPlotModel $w $station $Data(ObsTime) } reason] {
puts "Failed to build the model for $station : $reason"
}
LogMissingFields $station $Data(ObsTime)
set l [GetParameter $w Label]
SetParameter $l Hour $Data(ObsTime)
SetButtonStates $station $Data(ObsTime)
CleanupMemory $station $Data(ObsTime)
set Data($station,Update) 0
}
proc Item { station name hour where { opts "" } } {
return "( sp -35 -25 bd 65 50 al $where $opts tx \"\$Data($station,$name,$hour)\" )"
}	
set Model(StationCircle) "cs ht home pc black ft helv ( pc red pd cr 6 )"
set Model(Temperature)	"\[Item \$station Temperature \$hour top,left\]"
set Model(Pressure) 	"\[Item \$station Pressure \$hour top,right\]"
set Model(DewPoint)	"\[Item \$station DewPoint \$hour bottom,left\]"
set Model(Visibility)	"( sp -35 +6 \$Data(\$station,VisLocation,\$hour) tx \"\$Data(\$station,Visibility,\$hour)\" )"
set Model(ObsTime)	"( al bottom,centered tx \$obstime )"
set Model(Humidity)	"\[Item \$station Humidity \$hour bottom,left { pc darkgreen }\]"
set Model(WindDirection)	"( pu pc black rt \$Data(\$station,WindDirection,\$hour) fd 6 pd fd 30"
set Model(WindChill)	"\[Item \$station WindChill \$hour bottom,right { pc blue }\]"
set Model(Humidex)	"\[Item \$station Humidex \$hour bottom,right { pc red }\]"
set Model(CurrentWeather) "\[BuildCurrentWeather \$Data(\$station,CurrentWeather,\$hour)\]"
set Model(WindGusts)	"( )"
set Model(Tendency)	"( sp +12 +6 tx \"\$Data(\$station,Tendency,\$hour)\" )"
set Model(Station) 	"( sp -12 -36 tx \"\$station\" )"
set Model(Image)	"( sp -30 -30 im \"\$Data(\$station,Image,\$hour)\" )"
set Model(MissingData)	"cs home ht pc red ( al centered tx \"Data Missing\" )"
set Model(NotAvailable)	"cs home ht pc red ( al centered tx \"Not Available\" )"
set Model(MissingImage) "cs home ht pc red ( al centered tx \"No Image\" )"
set Model(IconName)	"home ( sp -12 +35 tx \"\[GetIconName \$Data(\$station,Icon,\$hour)\]\" )"
set Model(MaxTemp)	" ( sp -40 -15 tx \"Maximum \$Data(\$station,MaxTemp,\$hour) \$degrees\" )"
set Model(MinTemp)	" ( sp -40 -0 tx \"Minimum \$Data(\$station,MinTemp,\$hour) \$degrees\" )"
set Model(MeanTemp)	" ( sp -40 +15 tx \"Mean \$Data(\$station,MeanTemp,\$hour) \$degrees\" )"
set Model(WindCondition)	"home ( sy +35 al center,x tx \"\[FindDirectionName \$Data(\$station,WindDirection,\$hour)\] \$Data(\$station,WindSpeed,\$hour)\" )"
set Model(5) "( hm sp +\$where -4 rt 160 fd 10 )"
set Model(6) "( hm sp +\$where -4 rt 160 fd 8 lt 70 fd 4 )"
set Model(7) "( hm sp +\$where -4 rt 160 fd 8 lt 120 fd 6 )"
set Model(9) "( hm sp +\$where -4 rt 90 fd 2 rt 70 fd 10 )"
set Model(10) "( hm sp +\$where +0 rt 90 fd 6 )"
set Model(11) "( hm sp +\$where +4 rt 90 fd 2 lt 70 fd 10 )"
set Model(13) "( hm sp +\$where +4 rt 20 fd 8 rt 140 fd 4 )"
set Model(14) "( hm sp +\$where +4 rt 20 fd 8 rt 70 fd 4 )"
set Model(15) "( hm sp +\$where +4 rt 20 fd 10 )"
proc BuildCurrentWeather { str } {
set result "( al top,centered tx "
if { [string length $str] > 19 } {
set list [split $str]
if { [list length $list] < 2 } {
append result "\"$str\" )"
} else {
append result "\"[lindex $list 0]\" al centered,x "
append result "tx \"[lrange $list 1 end]\" )"
}
} else {
append result "\"$str\" )"
}
return $result
}
set Data(Directions) {
N 0 North NNE 22.5 NorthNorthEast NE 45 NorthEast ENE 67.5 EastNorthEast 
E 90 East ESE 112.5 EastSouthEast
SE 135 SouthEast SSE 157.5 SouthSouthEast S 180 South SSW 202.5 SouthSouthWest 
SW 225 SouthWest
WSW 247.5 WestSouthWest W 270 West WNW 292.5 WestNorthWest NW 310 NorthWest 
NNW 332.5 NorthNorthWest
}
proc FindDirection { name } {
global Data
foreach { n s l } $Data(Directions) {
if { $name == $n } { return $s }
}
return 0
}
proc FindDirectionName { angle } {
global Data
foreach { n s l } $Data(Directions) {
if { $angle == $s } {
return $l
}
}
return $angle
}
proc MakeSpeed { speed } {
global Data
if { $speed == $Data(MissingValue) } { return "" }
set speed [expr int($speed + 0.5)]
set fast [expr int($speed / 50)]
set full [expr int(($speed - ($fast * 50)) / 10)]
set half [expr int(($speed % 10) / 5)]
set str "lt 180"
while { $fast } {
append str " ( lt 105 fd 10 rt 177 fd 10 ) pu fd 4 pd"
incr fast -1
}
while { $full } {
append str " ( lt 105 fd 10 ) pu fd 4 pd"
incr full -1
}
while { $half } {
append str " ( lt 105 fd 6 ) pu fd 4 pd"
incr half -1
}
append str " )"
return $str
}
proc Blend { a b factor } {
return [expr int((1.0 - $factor) * $b + $factor * $a)]
}
proc ComputeColor { temp } {
set factor [expr ($temp + 50.0) / 100.0]
return "[Blend 200 0 $factor],0,[Blend 0 200 $factor]"
}
proc BuildPlotModel { w station hour } {
global Data 
global Model
set obstime [clock format $hour -format "%d/%H[IsEqual $Data(GMT) 1 Z \"\"]" -gmt $Data(GMT)]
switch $Data($station,Mode) {
3	{	if { $Data(DefaultUnits) == "" } {
set degrees "C"
} else { 
set degrees "F"
}
set Data(Model) "cs ht"
append Data(Model) " ( al top ft helv fs 10 tx \"Normals\" )"
if { $Data($station,HasNormals,$hour) } {
append Data(Model) $Model(MaxTemp)
append Data(Model) $Model(MinTemp)
append Data(Model) $Model(MeanTemp)
} else {
append Data(Model) " ( al centered tx \"Not available\" )"
}
append Data(Model) " ( al bottom ft helv fs 10 tx \"\$obstime\" )"
}
2	{	set Data(Model) "cs ht ( ft lucida,bold fs 50"
set color [ComputeColor $Data($station,Temperature,$hour)]
append Data(Model) " pc $color al centered tx \"\[string trim \$Data(\$station,Temperature,\$hour)\]\" )"
append Data(Model) " $Model(CurrentWeather)"
append Data(Model) " ( al bottom ft helv fs 10 tx \"\$obstime\" )"
}
1	{
set Data(Model) "cs ht"
append Data(Model) " $Model(CurrentWeather)"
append Data(Model) " $Model(Image)"
append Data(Model) " $Model(WindCondition)"
append Data(Model) " ( al bottom,right tx \"\$obstime\" )"
append Data(Model) " ( al bottom,left tx \"\[string trim \$Data(\$station,Temperature,\$hour)\]/\[string trim \$Data(\$station,DewPoint,\$hour)\]\" )" 
} 
0	{
set Data(Model) $Model(StationCircle)
foreach name $Data(Names) {
if { [GetData $station $name $hour] != $Data(MissingValue) } {
switch -exact -- $name {
"WindDirection"	{	append Data(Model) " $Model($name) [MakeSpeed [GetData $station WindSpeed $hour]]"
}
"TendencyCode"	{	if { [set code $Data($station,TendencyCode,$hour)] != $Data(MissingValue) } {
set where [expr [string length $Data($station,Tendency,$hour)] * 6 + 2 + 12]
append Data(Model) " [subst $Model($code)]"
}
}
"Icon"	-
"MslPressure"	-
"Image"	-
"WindSpeed"	-
"CloudAmount"	-
"VisLocation"	-
"MaxTemp"	-
"MinTemp"	-
"MeanTemp"	-
"Precip"	-
"Sunrise"	-
"Moonrise"	-
"Sunset"	-
"Moonset"	{ }
"Humidity"	{	if { [GetData $station DewPoint $hour] == $Data(MissingValue) } {
append Data(Model) " $Model($name)"
}
}
default	{	append Data(Model) " $Model($name)"
}
}	;}
}	;append Data(Model) " $Model(ObsTime) [DrawSkyCover $station $hour]"
}
}	;set Data($station,Pressure,$hour) [Pad [Millibars $Data($station,MslPressure,$hour)]]
set Data($station,Model) "[subst [subst $Data(Model)]]"
set since [expr [clock seconds] - $hour]
if { $since > 7200 } {
if { $Data($station,HasNext) == 0 && $Data($station,Update) == 1 } {
$w set -bg red
} else {
$w set -bg gray
}
} else {
$w set -bg gray
}
}
proc HandleButtonPress { w button x y } {
global Data VarList
$w set -relief sunken -state disabled
if { $button == 1 } {
set station [GetParameter $w Station]
if { [catch { UpdateStation $w $station } reason] } {
puts "Can't update $station : $reason"
}
} else {
catch { PlotTimeSeries [GetParameter $w Station] $VarList } 
}
$w set -state 1 -relief raised
}
proc GetIconName { name } {
return [file tail $name]
}
proc GetParameter { w name } {
set list [split [$w get -data] *]
set idx [lsearch -glob $list $name=*]
if { $idx == -1 } { return "" }
return [lindex [split [lindex $list $idx] =] 1]
}
proc SetParameter { w name value } {
set list [split [$w get -data] *]
set idx [lsearch -glob $list $name=*]
if { $idx == -1 } {
lappend list "$name=$value"
$w set -data [join $list *]
} else {
set list [lreplace $list $idx $idx "$name=$value"]
$w set -data [join $list *]
}
}
proc HandleModeChange { w button } {
global Data tcl_platform
set station [GetParameter $w Station]
if { $button == 1 } {
set Data($station,Mode) [expr ($Data($station,Mode) + 1) % 4]
set hour [GetParameter $w Hour]
foreach name $Data(Names) {
set Data($name) [GetData $station $name $hour]
}
BuildPlotModel [GetParameter $w Drawing] $station $hour
} else {
set query http://[MakeQuery $station]
if { $tcl_platform(platform) == "windows" } {
if { [catch { exec start $query } reason] } {
puts "Failed to start $query because : $reason"
}
} else {
if { [catch { exec $Data(Browser) $query & } reason] } {
puts "Failed to start $query because : $reason"
}
}
} 
}
proc HasDataForHour { station hour } {
global Data
set hasdata 0
foreach name $Data(Names) {
if { [GetData $station $name $hour] != $Data(MissingValue) } {
incr hasdata
}
}
return [IsEqual $hasdata 0 0 1]
}
proc PreviousObservations {} {
global Data
foreach station [split $Data(Station) ,] {
catch { PreviousObservation [Windows list $station,up] }
}
}
proc NextObservations {} {
global Data
foreach station [split $Data(Station) ,] {
catch { NextObservation [Windows list $station,down] }
}
}
proc ChangeModes {} {
global Data
foreach station [split $Data(Station) ,] {
catch { HandleModeChange [Windows list $station,label] }
}	
}
proc NextObservation { w } {
global Data
set station [GetParameter $w Station]
set label [GetParameter $w Label]
set hour [expr [GetParameter $label Hour] + 3600]
if { [HasDataForHour $station $hour] } {
if { [catch { BuildPlotModel [GetParameter $w Drawing] $station $hour } reason] } {
puts "Build : $reason"
}
SetParameter $label Hour $hour
SetButtonStates $station $hour
} else {
puts "No next observation for $station at [clock format $hour -gmt $Data(GMT)]"
}	
}
proc PreviousObservation { w } {
global Data
set station [GetParameter $w Station]
set label [GetParameter $w Label]
if { [catch { set hour [expr [GetParameter $label Hour] - 3600] } reason] } {
puts "Error : $reason"
}
if { [HasDataForHour $station $hour] } {
if { [catch { BuildPlotModel [GetParameter $w Drawing] $station $hour } reason] } {
puts "Build : $reason"
}
SetParameter $label Hour $hour
SetButtonStates $station $hour
} else {
puts "$station has no previous data for [clock format $hour -gmt $Data(GMT)]"
}	
}
proc SetButtonStates { station hour } {
global Data
set Data($station,HasNext) [HasDataForHour $station [expr $hour + 3600]]
set Data($station,HasPrev) [HasDataForHour $station [expr $hour - 3600]]
set Data(HasNext) $Data($station,HasNext)
set Data(HasPrev) $Data($station,HasPrev)
}
proc Filter { list station } {
set result {}
foreach item $list {
if { [lindex [split $item *] 0] == $station } {
lappend result $item
}
}
return $result
}
proc LoadFromDatabase { station } {
global Data
if { ! [file exists $Data(Database)] } {
return
}
if { [catch { set db [gdbm open $Data(Database) r] } reason] } {
puts "No history database available!"
return
}
set list [Filter [gdbm list $db] $station]
set now [clock seconds]
foreach item $list {
set parts [split $item *]
set valid [lindex $parts 1]
if { [expr $now - $valid] <= [expr $Data(HistoryLimit) * 3600] } {
set record [gdbm fetch $db $item]
foreach name $Data(Names) {
set Data($station,$name,$valid) $Data(MissingValue)
}
set elements [split $record *]
foreach element $elements {
set l [split $element =]
set Data($station,[lindex $l 0],$valid) [lindex $l 1]
}
}
}
gdbm close $db
}
proc DisplayCurrentHistory { station } {
global Data
set list [lsort [array names Data $station,*]]
catch { Destroy h }
Listbox h.h -w 600 -h 200
foreach ob $list {
set l [split $ob ,]
if { [llength $l] == 3 } {
set hour [lindex $l 2]
set name [lindex $l 1]
set valid [clock format $hour -gmt 1]
h.h add "$valid $name $Data($ob)"
}
}
Show h
Wm title h "Current history for $station"
} 
proc CleanupMemory { station hour } {
global Data
set when [expr $hour - ($Data(HistoryLimit) * 3600)]
foreach name $Data(Names) {
set key [MakeKey $station $name $when]
if { [info exists Data($key)] } {
catch { unset Data($key) }
}
}
}
proc TimeIndex { now then } {
set hours [expr 24 - ($now - $then) / 3600]
return $hours
}
source [file dirname [info script]]/timesubs.tcl
Bind Drawing <ButtonRelease> { %W set -relief raised }
catch { Destroy t }
set stations [split $Data(Station) ,]
set count [llength $stations]
if { $count < $Data(DefaultWidgets) } {
set f0 t
} else {
set itemsize 120 ;set windowsize [expr $Data(DefaultWidgets) * $itemsize]
set f0 [Scroll t.scroll -ystep $itemsize -scrollbars vertical \
-x 0 -y 0 -h $windowsize -w 114]
}
set f [Package $f0.all -o vertical -x 0 -y 0 -w 100]
if { $count > 1 && 1 == 0 } {
set g [Package $f.global -orientation horizontal -w 100 -x 0 -y 0]
RepeatButton $g.prev -text @2< -w 20 -command PreviousObservations \
-tooltip "Click to see the previous observations" \
-statevariable Data(HasPrev)
Button $g.update -text @menu -command "UpdateStationList $Data(Station)" \
-width 30 -tooltip "Click to update all stations" \
-statevariable Data(Update)
Button $g.mode -text @square -command ChangeModes \
-width 30 -tooltip "Click to change display mode" \
-statevariable Data(Update)
RepeatButton $g.next -text @2> -w 20 -command NextObservations \
-tooltip "Click to see the next observations" \
-statevariable Data(HasNext)
}
foreach s $stations {
set Data($s,HasPrev) 0
set Data($s,HasNext) 0
if { $Data(HasGdbm) } {
LoadFromDatabase $s
}
set Data($s,Mode) $Data(DefaultMode)
set Data($s,Model) "cs"
set f1 [Package $f.$s -w 100 -orientation vertical]
set f2 [Package $f1.buttons -w 100 -orientation horizontal]
RepeatButton $f2.up -text @2< -w 20 \
-data "Station=$s*Drawing=$f1.plot*Label=$f2.label" \
-tooltip "Display the previous observation for $s" \
-statevariable Data($s,HasPrev) \
-command { PreviousObservation %W }
Button $f2.label -text $s -w 60 \
-data "Station=$s*Drawing=$f1.plot" \
-tooltip "Click to change mode of $s" \
-command { HandleModeChange %W %b }
RepeatButton $f2.down -text @2> -w 20 \
-data "Station=$s*Drawing=$f1.plot*Label=$f2.label" \
-tooltip "Display the next observation for $s" \
-statevariable Data($s,HasNext) \
-command { NextObservation %W }
Drawing $f1.plot -relief raised -statevariable Data(Update) \
-tooltip "Click to update the observation for $s" \
-data "Station=$s*Label=$f2.label" -variable Data($s,Model)
Bind $f1.plot <ButtonPress> { HandleButtonPress %W %b %x %y}
}
Show t
Wm title t "Stn V1.00"
UpdateStationList $Data(Station)
