#!/bin/sh
# \
exec fltkwish "$0" ${1+"$@"}
#
# --- thermometer.tcl --- Display the station temperature in a thermometer widget
#
set Maps(Verbose) $tcl_interactive
set Maps(Url) http://www.theweathernetwork.com/weather/cities/can/pages/CAQC0363.htm
set Maps(FileName) temp.txt
#
package require httpcopy
#

# Call a function

proc call { what args } {

	if { [catch { eval $what $args } result] } {
		Log "$what : Failed : $result"
		}
	
	return $result
	}

# Something to handle parameter testing! Isn't Tcl wonderful!!!

proc IsEqual { src target { true 1 } { false 0 } } {

	if { [string tolower $src] == [string tolower $target] } {
		return $true
	} else {
		return $false
		}
	}
	
# Load the data from the web site

proc LoadData {} {

	global Maps

	set result {}
	
	::http::copy $Maps(Url) $Maps(FileName)
	
	if { [catch { open $Maps(FileName) r } fd] } {
		puts stderr "Failed to get the data!"
		return $result
		}
		
	set list [split [read $fd] \n]
	if { [set idx [lsearch -glob $list funcDisplayObs=*]] == -1 } {
		puts stderr "Did not find the data"
		return $result
		}
	
	return [lrange $list $idx [expr $idx + 6]]
	}
	
# Get the values from the observation

proc ExtractData { list } {

	global Data
		
	set data [split [string trim [lindex $list 3]] ,]
	
	regsub -all {&deg;F} [lindex $data 1] {F} tt
	regsub -all {&deg;F} [lindex $data 3] {F} td
	
	regsub -all {\"} [string trim $tt] {} Data(DryBulb)
	regsub -all {\"} [string trim $td] {} Data(WetBulb)
	
	# Get the observation date/time group
	
	set date [lindex [split [string trim [lindex $list 0] "\" "] ,] 2]
	set time [lindex [split [string trim [lindex $list 0] "\" "] ,] 3]
	
	regsub -all {<a(.)+\'>|</a>} $time {} time
		
	set Data(Date) [lindex [split $date] 3]
	set Data(Time) [string trim $time "\" "]
	
	set Data(DateTime) "$Data(Date) / $Data(Time)"
	
	
	}

proc Update { { recall 1 } } {

	global Data

	ExtractData [LoadData]	
	
	if { $recall } {
		after [expr 1800 * 1000] Update
	} else {
		puts "Current Temperature $Data(DryBulb) Deg. F and Dew Point $Data(WetBulb) Deg. F"
		}
	} 
	
# Create a thermometer widget with a label that shows the value

proc Therm { w  label name } {

	global Data
	
	set f [Package $w -w 60 -orientation vertical]
	Thermometer $f.therm -label $label -variable Data($name)
	Label $f.label -w 60 -variable Data($name) -label ""
	
	return $w
	}

Destroy t

Scheme plastic -bg silver

Option add Thermometer.liquid yellowgreen
Option add Thermometer.align bottom,center,inside
#Option add Thermometer.scale celcius

set f0 [Package t.all -orientation vertical -w 120]
Label $f0.label -variable Data(DateTime) -label "" -relief ridge \
        -tooltip "Click to update observation"
set f [Package $f0.all -orientation horizontal -w 120]
Therm $f.tt TT DryBulb
Therm $f.td TD WetBulb

Bind $f0.label <ButtonPress> { %W set -relief sunken ; call Update 0 ; %W set -relief ridge}

Show [Center t]

Wm title t "Montreal"

Update
