proc XLabel { v } {

	return [format %d [expr int(-(24.0 - $v)) - 1]]
	}

# Display a time series plot

proc PlotATimeSeries { w { station YUL } { what Temperature } } {

	global Data PlotDataTemp PlotDataDew PlotDataMsl PlotDataSpeed PlotDataDir
	
	set list [array names Data]
	
			switch -exact -- $what {
			
	Temperature	{	catch { unset PlotDataTemp }	}
	Pressure		{	catch { unset PlotDataMsl }	}
	DewPoint		{	catch { unset PlotDataDew }	}
	WindSpeed		{	catch { unset PlotDataSpeed }	}
	WindDirection	{	catch { unset PlotDataDir }	}
				} ;# End of switch cases
				
	foreach item $list {
		if { "$Data($item)" != "???" } {
			set parts [split $item ,]
			if { [llength $parts] == 3 && [lindex $parts 0] == $station && "[lindex $parts 2]" != "???" } {
				set hour [TimeIndex [clock seconds] [lindex $parts 2] ]
				set value [string trim $Data($item)]
				if { [lindex $parts 1] == $what } {
					switch -exact -- [lindex $parts 1] {
			
			Temperature	{	set PlotDataTemp($hour,$value,red) $value }
			Pressure		{	set value [expr $value + 1000]
							set PlotDataMsl($hour,$value,blue) $value }
			DewPoint		{	set PlotDataDew($hour,$value,green) $value
							}
			WindSpeed		{	set PlotDataSpeed($hour,$value) $value }
			WindDirection	{	set PlotDataDir($hour,$value) $value	}
			
			default		{	}
						} ;# End of switch cases
					} ;# If (what)...
				} ;# If statement
			} ;# If on missing data
		} ;# Foreach loop
		
	Destroy $w.$what
	
			switch -exact -- $what {
	
	Temperature			{	set yrange -40,40; set varname PlotDataTemp
							set ylabel "Deg. C"	
							}
	DewPoint				{	set yrange -40,40; set varname PlotDataDew
							set ylabel "Deg. C"
							}
	Pressure				{	set yrange 900,1050; set varname PlotDataMsl
							set ylabel "Millibars"
							}
	WindSpeed				{	set yrange 0,100; set varname PlotDataSpeed
							set ylabel "KM/H"
							}
	WindDirection			{	set yrange 0,360; set varname PlotDataDir
							set ylabel "Degrees"
							}
	
						} ;# End of switch cases
						
	
	XYPlot $w.$what -variable $varname -title $what -autolabel 1 -w 600 -h 200 \
		-xlabelcommand "XLabel %v" -grid true -xlabel "Time in Hours" \
		-ylabel $ylabel -gridlines 23.5,10.5 -xrange 0,24 -yrange $yrange -line true \

	return $w.$what
	}
				
# Plot the time series for a station

proc PlotTimeSeries { { station YUL } { what  Temperature } } {

	Destroy p
	
	Tabs p.p -w 600 -h 220

	foreach item $what {
		PlotATimeSeries p.p $station $item
		}
		
	Show p

	Wm title p "Time series for $station at [clock format [clock seconds] -gmt 1]"
	}
